@@ -2,7 +2,7 @@
 
 ########################################################################
 ##
-## Copyright (C) 2016-2021 The Octave Project Developers
+## Copyright (C) 2016-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -38,60 +38,62 @@ version="@PACKAGE_VERSION@"
 prefix="@prefix@"
 exec_prefix="@exec_prefix@"
 
-archlibdir=`echo "@archlibdir@" | sed "s|^${exec_prefix}/\\+||"`
-bindir=`echo "@bindir@" | sed "s|^${exec_prefix}/\\+||"`
-libdir=`echo "@libdir@" | sed "s|^${exec_prefix}/\\+||"`
-libexecdir=`echo "@libexecdir@" | sed "s|^${exec_prefix}/\\+||"`
-localapiarchlibdir=`echo "@localapiarchlibdir@" | sed "s|^${exec_prefix}/\\+||"`
-localapioctfiledir=`echo "@localapioctfiledir@" | sed "s|^${exec_prefix}/\\+||"`
-localarchlibdir=`echo "@localarchlibdir@" | sed "s|^${exec_prefix}/\\+||"`
-localoctfiledir=`echo "@localoctfiledir@" | sed "s|^${exec_prefix}/\\+||"`
-localverarchlibdir=`echo "@localverarchlibdir@" | sed "s|^${exec_prefix}/\\+||"`
-localveroctfiledir=`echo "@localveroctfiledir@" | sed "s|^${exec_prefix}/\\+||"`
-octfiledir=`echo "@octfiledir@" | sed "s|^${exec_prefix}/\\+||"`
-octlibdir=`echo "@octlibdir@" | sed "s|^${exec_prefix}/\\+||"`
+archlibdir=`echo "@archlibdir@" | $SED "s|^${exec_prefix}/\\+||"`
+bindir=`echo "@bindir@" | $SED "s|^${exec_prefix}/\\+||"`
+libdir=`echo "@libdir@" | $SED "s|^${exec_prefix}/\\+||"`
+libexecdir=`echo "@libexecdir@" | $SED "s|^${exec_prefix}/\\+||"`
+localapiarchlibdir=`echo "@localapiarchlibdir@" | $SED "s|^${exec_prefix}/\\+||"`
+localapioctfiledir=`echo "@localapioctfiledir@" | $SED "s|^${exec_prefix}/\\+||"`
+localarchlibdir=`echo "@localarchlibdir@" | $SED "s|^${exec_prefix}/\\+||"`
+localoctfiledir=`echo "@localoctfiledir@" | $SED "s|^${exec_prefix}/\\+||"`
+localverarchlibdir=`echo "@localverarchlibdir@" | $SED "s|^${exec_prefix}/\\+||"`
+localveroctfiledir=`echo "@localveroctfiledir@" | $SED "s|^${exec_prefix}/\\+||"`
+octfiledir=`echo "@octfiledir@" | $SED "s|^${exec_prefix}/\\+||"`
+octlibdir=`echo "@octlibdir@" | $SED "s|^${exec_prefix}/\\+||"`
 
-datadir=`echo "@datadir@" | sed "s|^${prefix}/\\+||"`
-datarootdir=`echo "@datarootdir@" | sed "s|^${prefix}/\\+||"`
-doc_cache_file=`echo "@doc_cache_file@" | sed "s|^${prefix}/\\+||"`
-exec_prefix=`echo "@exec_prefix@" | sed "s|^${prefix}/\\+||"`
-fcnfiledir=`echo "@fcnfiledir@" | sed "s|^${prefix}/\\+||"`
-imagedir=`echo "@imagedir@" | sed "s|^${prefix}/\\+||"`
-includedir=`echo "@includedir@" | sed "s|^${prefix}/\\+||"`
-infodir=`echo "@infodir@" | sed "s|^${prefix}/\\+||"`
-infofile=`echo "@infofile@" | sed "s|^${prefix}/\\+||"`
-localapifcnfiledir=`echo "@localapifcnfiledir@" | sed "s|^${prefix}/\\+||"`
-localfcnfiledir=`echo "@localfcnfiledir@" | sed "s|^${prefix}/\\+||"`
-localstartupfiledir=`echo "@localstartupfiledir@" | sed "s|^${prefix}/\\+||"`
-localapiarchlibdir=`echo "@localapiarchlibdir@" | sed "s|^${prefix}/\\+||"`
-localverfcnfiledir=`echo "@localverfcnfiledir@" | sed "s|^${prefix}/\\+||"`
-man1dir=`echo "@man1dir@" | sed "s|^${prefix}/\\+||"`
-mandir=`echo "@mandir@" | sed "s|^${prefix}/\\+||"`
-octdatadir=`echo "@octdatadir@" | sed "s|^${prefix}/\\+||"`
-octdocdir=`echo "@octdocdir@" | sed "s|^${prefix}/\\+||"`
-octetcdir=`echo "@octetcdir@" | sed "s|^${prefix}/\\+||"`
-octfontsdir=`echo "@octfontsdir@" | sed "s|^${prefix}/\\+||"`
-octincludedir=`echo "@octincludedir@" | sed "s|^${prefix}/\\+||"`
-octlocaledir=`echo "@octlocaledir@" | sed "s|^${prefix}/\\+||"`
-octtestsdir=`echo "@octtestsdir@" | sed "s|^${prefix}/\\+||"`
-startupfiledir=`echo "@startupfiledir@" | sed "s|^${prefix}/\\+||"`
-texi_macros_file=`echo "@texi_macros_file@" | sed "s|^${prefix}/\\+||"`
+datadir=`echo "@datadir@" | $SED "s|^${prefix}/\\+||"`
+datarootdir=`echo "@datarootdir@" | $SED "s|^${prefix}/\\+||"`
+doc_cache_file=`echo "@doc_cache_file@" | $SED "s|^${prefix}/\\+||"`
+exec_prefix=`echo "@exec_prefix@" | $SED "s|^${prefix}/\\+||"`
+fcnfiledir=`echo "@fcnfiledir@" | $SED "s|^${prefix}/\\+||"`
+imagedir=`echo "@imagedir@" | $SED "s|^${prefix}/\\+||"`
+includedir=`echo "@includedir@" | $SED "s|^${prefix}/\\+||"`
+infodir=`echo "@infodir@" | $SED "s|^${prefix}/\\+||"`
+infofile=`echo "@infofile@" | $SED "s|^${prefix}/\\+||"`
+localapifcnfiledir=`echo "@localapifcnfiledir@" | $SED "s|^${prefix}/\\+||"`
+localfcnfiledir=`echo "@localfcnfiledir@" | $SED "s|^${prefix}/\\+||"`
+localstartupfiledir=`echo "@localstartupfiledir@" | $SED "s|^${prefix}/\\+||"`
+localapiarchlibdir=`echo "@localapiarchlibdir@" | $SED "s|^${prefix}/\\+||"`
+localverfcnfiledir=`echo "@localverfcnfiledir@" | $SED "s|^${prefix}/\\+||"`
+man1dir=`echo "@man1dir@" | $SED "s|^${prefix}/\\+||"`
+mandir=`echo "@mandir@" | $SED "s|^${prefix}/\\+||"`
+octdatadir=`echo "@octdatadir@" | $SED "s|^${prefix}/\\+||"`
+octdocdir=`echo "@octdocdir@" | $SED "s|^${prefix}/\\+||"`
+octetcdir=`echo "@octetcdir@" | $SED "s|^${prefix}/\\+||"`
+octfontsdir=`echo "@octfontsdir@" | $SED "s|^${prefix}/\\+||"`
+octincludedir=`echo "@octincludedir@" | $SED "s|^${prefix}/\\+||"`
+octlocaledir=`echo "@octlocaledir@" | $SED "s|^${prefix}/\\+||"`
+octtestsdir=`echo "@octtestsdir@" | $SED "s|^${prefix}/\\+||"`
+startupfiledir=`echo "@startupfiledir@" | $SED "s|^${prefix}/\\+||"`
+texi_macros_file=`echo "@texi_macros_file@" | $SED "s|^${prefix}/\\+||"`
 
+## FIXME: Some of these flags might contain double quotes.
+##        Is it ok to use single quotes here?
 if [ "x@OCTAVE_RELOCATE_ALL@" = "xyes" ]; then
   ## Replace portions of compiler flags that depend on prefix on target
-  cppflags=`echo "@CPPFLAGS@" | sed "s|@prefix@|\$\{prefix\}|g"`
-  fftw3f_ldflags=`echo "@FFTW3F_LDFLAGS@" | sed "s|@prefix@|\$\{prefix\}|g"`
-  fftw3_ldflags=`echo "@FFTW3_LDFLAGS@" | sed "s|@prefix@|\$\{prefix\}|g"`
-  flibs=`echo "@FLIBS@" | sed "s|@prefix@|\$\{prefix\}|g"`
-  ldflags=`echo "@LDFLAGS@" | sed "s|@prefix@|\$\{prefix\}|g"`
-  oct_link_opts=`echo "@OCT_LINK_OPTS@" | sed "s|@prefix@|\$\{prefix\}|g"`
+  cppflags=`echo '@CPPFLAGS@' | $SED "s|@prefix@|\$\{prefix\}|g" | $SED 's|\"|\\\\\\\"|g'`
+  fftw3f_ldflags=`echo '@FFTW3F_LDFLAGS@' | $SED "s|@prefix@|\$\{prefix\}|g" | $SED 's|\"|\\\\\\\"|g'`
+  fftw3_ldflags=`echo '@FFTW3_LDFLAGS@' | $SED "s|@prefix@|\$\{prefix\}|g" | $SED 's|\"|\\\\\\\"|g'`
+  flibs=`echo '@FLIBS@' | $SED "s|@prefix@|\$\{prefix\}|g" | $SED 's|\"|\\\\\\\"|g'`
+  ldflags=`echo '@LDFLAGS@' | $SED "s|@prefix@|\$\{prefix\}|g" | $SED 's|\"|\\\\\\\"|g'`
+  oct_link_opts=`echo '@OCT_LINK_OPTS@' | $SED "s|@prefix@|\$\{prefix\}|g" | $SED 's|\"|\\\\\\\"|g'`
 else
-  cppflags="@CPPFLAGS@"
-  fftw3f_ldflags="@FFTW3F_LDFLAGS@"
-  fftw3_ldflags="@FFTW3_LDFLAGS@"
-  flibs="@FLIBS@"
-  ldflags="@LDFLAGS@"
-  oct_link_opts="@OCT_LINK_OPTS@"
+  cppflags=`echo '@CPPFLAGS@' | $SED 's|\"|\\\\\\\"|g'`
+  fftw3f_ldflags=`echo '@FFTW3F_LDFLAGS@' | $SED 's|\"|\\\\\\\"|g'`
+  fftw3_ldflags=`echo '@FFTW3_LDFLAGS@' | $SED 's|\"|\\\\\\\"|g'`
+  flibs=`echo '@FLIBS@' | $SED 's|\"|\\\\\\\"|g'`
+  ldflags=`echo '@LDFLAGS@' | $SED 's|\"|\\\\\\\"|g'`
+  oct_link_opts=`echo '@OCT_LINK_OPTS@' | $SED 's|\"|\\\\\\\"|g'`
 fi
 
 
@@ -178,9 +180,6 @@ LFLAGS="@LFLAGS@"
 LIBOCTAVE="@LIBOCTAVE@"
 LIBOCTINTERP="@LIBOCTINTERP@"
 LIBS="@LIBS@"
-LLVM_CPPFLAGS="@LLVM_CPPFLAGS@"
-LLVM_LDFLAGS="@LLVM_LDFLAGS@"
-LLVM_LIBS="@LLVM_LIBS@"
 LN_S="@LN_S@"
 MAGICK_CPPFLAGS="@MAGICK_CPPFLAGS@"
 MAGICK_LDFLAGS="@MAGICK_LDFLAGS@"
@@ -214,7 +213,7 @@ QT_LIBS="@QT_LIBS@"
 QT_OPENGL_LIBS="@QT_OPENGL_LIBS@"
 RANLIB="@RANLIB@"
 RDYNAMIC_FLAG="@RDYNAMIC_FLAG@"
-READLINE_LIBS="@READLINE_LIBS@"
+READLINE_LIBS="@LIBREADLINE@"
 SHARED_LIBS="@SHARED_LIBS@"
 SH_LDFLAGS="@SH_LDFLAGS@"
 STATIC_LIBS="@STATIC_LIBS@"
@@ -228,7 +227,6 @@ SUNDIALS_NVECSERIAL_LIBS="@SUNDIALS_NVECSERIAL_LIBS@"
 SUNDIALS_SUNLINSOLKLU_CPPFLAGS="@SUNDIALS_SUNLINSOLKLU_CPPFLAGS@"
 SUNDIALS_SUNLINSOLKLU_LDFLAGS="@SUNDIALS_SUNLINSOLKLU_LDFLAGS@"
 SUNDIALS_SUNLINSOLKLU_LIBS="@SUNDIALS_SUNLINSOLKLU_LIBS@"
-TERM_LIBS="@TERM_LIBS@"
 UMFPACK_CPPFLAGS="@UMFPACK_CPPFLAGS@"
 UMFPACK_LDFLAGS="@UMFPACK_LDFLAGS@"
 UMFPACK_LIBS="@UMFPACK_LIBS@"
@@ -340,9 +338,6 @@ $SED \
   -e "s|%OCTAVE_CONF_LIBOCTAVE%|\"${LIBOCTAVE}\"|" \
   -e "s|%OCTAVE_CONF_LIBOCTINTERP%|\"${LIBOCTINTERP}\"|" \
   -e "s|%OCTAVE_CONF_LIBS%|\"${LIBS}\"|" \
-  -e "s|%OCTAVE_CONF_LLVM_CPPFLAGS%|\"${LLVM_CPPFLAGS}\"|" \
-  -e "s|%OCTAVE_CONF_LLVM_LDFLAGS%|\"${LLVM_LDFLAGS}\"|" \
-  -e "s|%OCTAVE_CONF_LLVM_LIBS%|\"${LLVM_LIBS}\"|" \
   -e "s|%OCTAVE_CONF_LN_S%|\"${LN_S}\"|" \
   -e "s|%OCTAVE_CONF_MAGICK_CPPFLAGS%|\"${MAGICK_CPPFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_MAGICK_LDFLAGS%|\"${MAGICK_LDFLAGS}\"|" \
@@ -395,7 +390,6 @@ $SED \
   -e "s|%OCTAVE_CONF_SUNDIALS_SUNLINSOLKLU_CPPFLAGS%|\"${SUNDIALS_SUNLINSOLKLU_CPPFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_SUNDIALS_SUNLINSOLKLU_LDFLAGS%|\"${SUNDIALS_SUNLINSOLKLU_LDFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_SUNDIALS_SUNLINSOLKLU_LIBS%|\"${SUNDIALS_SUNLINSOLKLU_LIBS}\"|" \
-  -e "s|%OCTAVE_CONF_TERM_LIBS%|\"${TERM_LIBS}\"|" \
   -e "s|%OCTAVE_CONF_UMFPACK_CPPFLAGS%|\"${UMFPACK_CPPFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_UMFPACK_LDFLAGS%|\"${UMFPACK_LDFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_UMFPACK_LIBS%|\"${UMFPACK_LIBS}\"|" \
