@@ -3,7 +3,7 @@
 // This class provides a simple color picker based on tQColorButton
 // by Harald Jedele, 23.03.01, GPL version 2 or any later version.
 //
-// Copyright (C) 2013-2021 The Octave Project Developers
+// Copyright (C) 2013-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -32,28 +32,31 @@
 #include <QColorDialog>
 #include <QPushButton>
 
-namespace octave
+OCTAVE_BEGIN_NAMESPACE(octave)
+
+class color_picker : public QPushButton
 {
-  class color_picker : public QPushButton
-  {
-    Q_OBJECT
+  Q_OBJECT
 
-  public:
+public:
 
-    color_picker (QColor color = QColor (0, 0, 0), QWidget *parent = nullptr);
+  color_picker (QColor color = QColor (0, 0, 0), QWidget *parent = nullptr);
 
-    QColor color (void) const { return m_color; }
+  QColor color (void) const { return m_color; }
 
-  private slots:
+  void set_color (QColor new_color);
 
-    void select_color (void);
+private slots:
 
-  private:
+  void select_color (void);
 
-    virtual void update_button (void);
+private:
 
-    QColor m_color;
-  };
-}
+  virtual void update_button (void);
+
+  QColor m_color;
+};
+
+OCTAVE_END_NAMESPACE(octave)
 
 #endif
