@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2005-2022 The Octave Project Developers
+// Copyright (C) 2005-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -45,7 +45,7 @@
 #include "parse.h"
 #include "variables.h"
 
-OCTAVE_NAMESPACE_BEGIN
+OCTAVE_BEGIN_NAMESPACE(octave)
 
 #if defined (HAVE_ARPACK)
 
@@ -195,7 +195,7 @@ Undocumented internal function.
   SparseComplexMatrix ascm, bscm, bsct;
   int b_arg = 0;
   bool have_b = false;
-  bool have_a_fun = false;
+  bool have_a_fcn = false;
   bool a_is_complex = false;
   bool b_is_complex = false;
   bool symmetric = false;
@@ -234,7 +234,7 @@ Undocumented internal function.
 
       n = args(1).nint_value ();
       arg_offset = 1;
-      have_a_fun = true;
+      have_a_fcn = true;
     }
   else
     {
@@ -327,7 +327,8 @@ Undocumented internal function.
       if (! args(3+arg_offset).isstruct ())
         error ("eigs: OPTS argument must be a structure");
 
-      octave_scalar_map map = args(3+arg_offset).xscalar_map_value ("eigs: OPTS argument must be a scalar structure");
+      octave_scalar_map map = args(3
+                                   +arg_offset).xscalar_map_value ("eigs: OPTS argument must be a scalar structure");
 
       octave_value tmp;
 
@@ -343,7 +344,7 @@ Undocumented internal function.
         }
 
       // isreal is ignored if A is not a function
-      if (have_a_fun)
+      if (have_a_fcn)
         {
           tmp = map.getfield ("isreal");
           if (tmp.is_defined ())
@@ -398,7 +399,7 @@ Undocumented internal function.
     error ("eigs: incorrect number of arguments");
 
   // Test undeclared (no issym) matrix inputs for symmetry
-  if (! sym_tested && ! have_a_fun)
+  if (! sym_tested && ! have_a_fcn)
     {
       if (a_is_complex)
         {
@@ -445,14 +446,14 @@ Undocumented internal function.
       EigsComplexFunc
       eigs_complex_fcn = [&callback] (const ComplexColumnVector& x,
                                       int& eigs_error)
-                           {
-                             return callback.eigs_complex_func (x, eigs_error);
-                           };
+      {
+        return callback.eigs_complex_func (x, eigs_error);
+      };
 
       ComplexMatrix eig_vec;
       ComplexColumnVector eig_val;
 
-      if (have_a_fun)
+      if (have_a_fcn)
         {
           if (b_is_sparse)
             nconv = EigsComplexNonSymmetricFunc
@@ -512,15 +513,15 @@ Undocumented internal function.
       EigsComplexFunc
       eigs_complex_fcn = [&callback] (const ComplexColumnVector& x,
                                       int& eigs_error)
-                           {
-                             return callback.eigs_complex_func (x, eigs_error);
-                           };
+      {
+        return callback.eigs_complex_func (x, eigs_error);
+      };
 
       // Promote real problem to a complex one.
       ComplexMatrix eig_vec;
       ComplexColumnVector eig_val;
 
-      if (have_a_fun)
+      if (have_a_fcn)
         {
           if (b_is_sparse)
             nconv = EigsComplexNonSymmetricFunc
@@ -565,16 +566,16 @@ Undocumented internal function.
   else
     {
       EigsFunc eigs_fcn = [&callback] (const ColumnVector& x, int& eigs_error)
-                            {
-                              return callback.eigs_func (x, eigs_error);
-                            };
+      {
+        return callback.eigs_func (x, eigs_error);
+      };
 
       if (symmetric)
         {
           Matrix eig_vec;
           ColumnVector eig_val;
 
-          if (have_a_fun)
+          if (have_a_fcn)
             {
               if (b_is_sparse)
                 nconv = EigsRealSymmetricFunc
@@ -624,7 +625,7 @@ Undocumented internal function.
           ComplexMatrix eig_vec;
           ComplexColumnVector eig_val;
 
-          if (have_a_fun)
+          if (have_a_fcn)
             {
               if (b_is_sparse)
                 nconv = EigsRealNonSymmetricFunc
@@ -707,4 +708,4 @@ Undocumented internal function.
 %!assert (1)
 */
 
-OCTAVE_NAMESPACE_END
+OCTAVE_END_NAMESPACE(octave)
