@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2000-2022 The Octave Project Developers
+// Copyright (C) 2000-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -33,7 +33,7 @@
 
 #include "c-file-ptr-stream.h"
 
-OCTAVE_NAMESPACE_BEGIN
+OCTAVE_BEGIN_NAMESPACE(octave)
 
 #if ! defined (SEEK_SET)
 #  define SEEK_SET 0
@@ -320,4 +320,4 @@ c_zfile_ptr_buf::buf_close (void)
 
 #endif
 
-OCTAVE_NAMESPACE_END
+OCTAVE_END_NAMESPACE(octave)
