@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1998-2022 The Octave Project Developers
+// Copyright (C) 1998-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -46,7 +46,7 @@
 #include "ovl.h"
 #include "pager.h"
 
-OCTAVE_NAMESPACE_BEGIN
+OCTAVE_BEGIN_NAMESPACE(octave)
 
 // The symmetric column elimination tree code take from the Davis LDL code.
 // Copyright given elsewhere in this file.
@@ -313,7 +313,7 @@ Laboratory.  (see @url{http://faculty.cse.tamu.edu/davis/suitesparse.html})
           if (knobs[COLAMD_DENSE_ROW] >= 0)
             octave_stdout << "knobs(1): " << User_knobs (0)
                           << ", rows with > max (16,"
-                          << knobs[COLAMD_DENSE_ROW] << "*sqrt (columns(A)))"
+                          << knobs[COLAMD_DENSE_ROW] << "* sqrt (columns(A)))"
                           << " entries removed\n";
           else
             octave_stdout << "knobs(1): " << User_knobs (0)
@@ -322,7 +322,7 @@ Laboratory.  (see @url{http://faculty.cse.tamu.edu/davis/suitesparse.html})
           if (knobs[COLAMD_DENSE_COL] >= 0)
             octave_stdout << "knobs(2): " << User_knobs (1)
                           << ", cols with > max (16,"
-                          << knobs[COLAMD_DENSE_COL] << "*sqrt (size(A)))"
+                          << knobs[COLAMD_DENSE_COL] << "* sqrt (size(A)))"
                           << " entries removed\n";
           else
             octave_stdout << "knobs(2): " << User_knobs (1)
@@ -786,4 +786,4 @@ permutations on the tree.
 %!error <is not square> etree (sprand (2, 4, .25))
 */
 
-OCTAVE_NAMESPACE_END
+OCTAVE_END_NAMESPACE(octave)
