@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -144,18 +144,25 @@ hdf5_fstreambase::open_create (const char *name, int mode)
 #if defined (HAVE_HDF5)
   // Open the HDF5 file NAME.  If it does not exist, create the file.
 
+#  if defined (HAVE_HDF5_UTF8)
+  const char *fname = name;
+#  else
   std::string fname_str (name);
   std::string ascii_fname_str = octave::sys::get_ASCII_filename (fname_str);
-  const char *ascii_fname = ascii_fname_str.c_str ();
+  const char *fname = ascii_fname_str.c_str ();
+#  endif
 
   if (mode & std::ios::in)
-    file_id = H5Fopen (ascii_fname, H5F_ACC_RDONLY, octave_H5P_DEFAULT);
+    file_id = H5Fopen (fname, H5F_ACC_RDONLY, octave_H5P_DEFAULT);
   else if (mode & std::ios::out)
     {
-      if (mode & std::ios::app && H5Fis_hdf5 (ascii_fname) > 0)
-        file_id = H5Fopen (ascii_fname, H5F_ACC_RDWR, octave_H5P_DEFAULT);
+      if (mode & std::ios::app && H5Fis_hdf5 (fname) > 0)
+        file_id = H5Fopen (fname, H5F_ACC_RDWR, octave_H5P_DEFAULT);
       else
-#  if defined (OCTAVE_USE_WINDOWS_API)
+#  if defined (HAVE_HDF5_UTF8)
+        file_id = H5Fcreate (fname, H5F_ACC_TRUNC, octave_H5P_DEFAULT,
+                             octave_H5P_DEFAULT);
+#  else
         {
           // Check whether file already exists
           std::string abs_ascii_fname
@@ -163,7 +170,7 @@ hdf5_fstreambase::open_create (const char *name, int mode)
           if (! abs_ascii_fname.empty ())
             {
               // Use the existing file
-              file_id = H5Fcreate (ascii_fname, H5F_ACC_TRUNC,
+              file_id = H5Fcreate (fname, H5F_ACC_TRUNC,
                                    octave_H5P_DEFAULT, octave_H5P_DEFAULT);
               if (file_id < 0)
                 std::ios::setstate (std::ios::badbit);
@@ -174,7 +181,7 @@ hdf5_fstreambase::open_create (const char *name, int mode)
           // Check whether filename contains non-ASCII (UTF-8) characters.
           std::string::const_iterator first_non_ASCII
             = std::find_if (fname_str.begin (), fname_str.end (),
-                            [](char c) { return (c < 0 || c >= 128); });
+          [](char c) { return (c < 0 || c >= 128); });
           if (first_non_ASCII == fname_str.end ())
             {
               // No non-ASCII characters
@@ -216,9 +223,6 @@ hdf5_fstreambase::open_create (const char *name, int mode)
           ascii_fname = ascii_fname_str.c_str ();
           file_id = H5Fopen (ascii_fname, H5F_ACC_RDWR, octave_H5P_DEFAULT);
         }
-#  else
-        file_id = H5Fcreate (name, H5F_ACC_TRUNC, octave_H5P_DEFAULT,
-                             octave_H5P_DEFAULT);
 #  endif
     }
   if (file_id < 0)
@@ -303,17 +307,17 @@ hdf5_check_attr (octave_hdf5_id loc_id, const char *attr_name)
   // HDF5 doesn't print out all sorts of error messages if we
   // call H5Aopen for a non-existing attribute
 
-  H5E_auto_t err_func;
-  void *err_func_data;
+  H5E_auto_t err_fcn;
+  void *err_fcn_data;
 
   // turn off error reporting temporarily, but save the error
   // reporting function:
 
 #if defined (HAVE_HDF5_18)
-  H5Eget_auto (octave_H5E_DEFAULT, &err_func, &err_func_data);
+  H5Eget_auto (octave_H5E_DEFAULT, &err_fcn, &err_fcn_data);
   H5Eset_auto (octave_H5E_DEFAULT, nullptr, nullptr);
 #else
-  H5Eget_auto (&err_func, &err_func_data);
+  H5Eget_auto (&err_fcn, &err_fcn_data);
   H5Eset_auto (nullptr, nullptr);
 #endif
 
@@ -328,9 +332,9 @@ hdf5_check_attr (octave_hdf5_id loc_id, const char *attr_name)
 
   // restore error reporting:
 #if defined (HAVE_HDF5_18)
-  H5Eset_auto (octave_H5E_DEFAULT, err_func, err_func_data);
+  H5Eset_auto (octave_H5E_DEFAULT, err_fcn, err_fcn_data);
 #else
-  H5Eset_auto (err_func, err_func_data);
+  H5Eset_auto (err_fcn, err_fcn_data);
 #endif
   return retval;
 
@@ -351,17 +355,17 @@ hdf5_get_scalar_attr (octave_hdf5_id loc_id, octave_hdf5_id type_id,
   // HDF5 doesn't print out all sorts of error messages if we
   // call H5Aopen for a non-existing attribute
 
-  H5E_auto_t err_func;
-  void *err_func_data;
+  H5E_auto_t err_fcn;
+  void *err_fcn_data;
 
   // turn off error reporting temporarily, but save the error
   // reporting function:
 
 #if defined (HAVE_HDF5_18)
-  H5Eget_auto (octave_H5E_DEFAULT, &err_func, &err_func_data);
+  H5Eget_auto (octave_H5E_DEFAULT, &err_fcn, &err_fcn_data);
   H5Eset_auto (octave_H5E_DEFAULT, nullptr, nullptr);
 #else
-  H5Eget_auto (&err_func, &err_func_data);
+  H5Eget_auto (&err_fcn, &err_fcn_data);
   H5Eset_auto (nullptr, nullptr);
 #endif
 
@@ -380,9 +384,9 @@ hdf5_get_scalar_attr (octave_hdf5_id loc_id, octave_hdf5_id type_id,
 
   // restore error reporting:
 #if defined (HAVE_HDF5_18)
-  H5Eset_auto (octave_H5E_DEFAULT, err_func, err_func_data);
+  H5Eset_auto (octave_H5E_DEFAULT, err_fcn, err_fcn_data);
 #else
-  H5Eset_auto (err_func, err_func_data);
+  H5Eset_auto (err_fcn, err_fcn_data);
 #endif
   return retval;
 
@@ -618,8 +622,7 @@ load_inline_fcn (hid_t loc_id, const char *name, octave_value& retval)
 
   args(0) = std::string (iftext_tmp);
 
-  octave::interpreter& interp
-    = octave::__get_interpreter__ ("load_inline_fcn");
+  octave::interpreter& interp = octave::__get_interpreter__ ();
 
   octave_value_list tmp = interp.feval ("inline", args, 1);
 
@@ -660,7 +663,7 @@ hdf5_read_next_data_internal (hid_t group_id, const char *name, void *dv)
   hid_t type_class_id = -1;
   hid_t data_id = -1;
   hid_t subgroup_id = -1;
-  hid_t space_id = -1;;
+  hid_t space_id = -1;
 
   H5G_stat_t info;
   herr_t retval = 0;
@@ -668,8 +671,7 @@ hdf5_read_next_data_internal (hid_t group_id, const char *name, void *dv)
 
   std::string vname = name;
 
-  octave::type_info& type_info
-    = octave::__get_type_info__ ("hdf5_read_next_data_internal");
+  octave::type_info& type_info = octave::__get_type_info__ ();
 
   // Allow identifiers as all digits so we can load lists saved by
   // earlier versions of Octave.
@@ -1080,7 +1082,7 @@ read_hdf5_data (std::istream& is, const std::string& /* filename */,
 {
 #if defined (HAVE_HDF5)
 
-  check_hdf5_types ();
+  octave::check_hdf5_types ();
 
   std::string retval;
 
@@ -1268,7 +1270,8 @@ save_hdf5_empty (octave_hdf5_id loc_id, const char *name, const dim_vector& d)
   if (space_hid < 0) return space_hid;
 #if defined (HAVE_HDF5_18)
   data_hid = H5Dcreate (loc_id, name, H5T_NATIVE_IDX, space_hid,
-                        octave_H5P_DEFAULT, octave_H5P_DEFAULT, octave_H5P_DEFAULT);
+                        octave_H5P_DEFAULT, octave_H5P_DEFAULT,
+                        octave_H5P_DEFAULT);
 #else
   data_hid = H5Dcreate (loc_id, name, H5T_NATIVE_IDX, space_hid,
                         octave_H5P_DEFAULT);
@@ -1501,7 +1504,7 @@ save_hdf5_data (std::ostream& os, const octave_value& tc,
 {
 #if defined (HAVE_HDF5)
 
-  check_hdf5_types ();
+  octave::check_hdf5_types ();
 
   hdf5_ofstream& hs = dynamic_cast<hdf5_ofstream&> (os);
 
