@@ -130,14 +130,14 @@ Compute the inverse cosine in radians for each element of @var{x}.
 
 ## Test large magnitude arguments (bug #45507)
 ## Test fails with older versions of libm, solution is to upgrade.
-%!testif ; ! ismac () && ! ispc ()   <*45507>
+%!testif ; ! __have_feature__ ("LLVM_LIBCXX") && ! ispc ()  <*45507>
 %! x = [1, -1, i, -i] .* 1e150;
 %! v = [0, pi, pi/2, pi/2];
 %! assert (real (acos (x)), v);
 
-%!testif ; ismac () || ispc ()   <52627>
-%! ## Same test code as above, but intended only for test statistics on Mac and
-%! ## Windows.  Their trig/hyperbolic functions have huge tolerances.
+%!testif ; __have_feature__ ("LLVM_LIBCXX") || ispc ()  <52627>
+%! ## Same test code as above, but intended for test statistics with libc++ or
+%! ## on Windows.  Their trig/hyperbolic functions have huge tolerances.
 %! x = [1, -1, i, -i] .* 1e150;
 %! v = [0, pi, pi/2, pi/2];
 %! assert (real (acos (x)), v);
@@ -202,14 +202,14 @@ Compute the inverse hyperbolic cosine for each element of @var{x}.
 
 ## Test large magnitude arguments (bug #45507)
 ## Test fails with older versions of libm, solution is to upgrade.
-%!testif ; ! ismac () && ! ispc ()   <*45507>
+%!testif ; ! __have_feature__ ("LLVM_LIBCXX") && ! ispc ()  <*45507>
 %! x = [1, -1, i, -i] .* 1e150;
 %! v = [0, pi, pi/2, -pi/2];
 %! assert (imag (acosh (x)), v);
 
-%!testif ; ismac () || ispc ()   <52627>
-%! ## Same test code as above, but intended only for test statistics on Mac and
-%! ## Windows.  Their trig/hyperbolic functions have huge tolerances.
+%!testif ; __have_feature__ ("LLVM_LIBCXX") || ispc ()  <52627>
+%! ## Same test code as above, but intended for test statistics with libc++ or
+%! ## on Windows.  Their trig/hyperbolic functions have huge tolerances.
 %! x = [1, -1, i, -i] .* 1e150;
 %! v = [0, pi, pi/2, -pi/2];
 %! assert (imag (acosh (x)), v);
@@ -336,14 +336,14 @@ Compute the inverse sine in radians for each element of @var{x}.
 
 ## Test large magnitude arguments (bug #45507)
 ## Test fails with older versions of libm, solution is to upgrade.
-%!testif ; ! ismac () && ! ispc ()   <*45507>
+%!testif ; ! __have_feature__ ("LLVM_LIBCXX") && ! ispc ()  <*45507>
 %! x = [1, -1, i, -i] .* 1e150;
 %! v = [pi/2, -pi/2, 0, -0];
 %! assert (real (asin (x)), v);
 
-%!testif ; ismac () || ispc ()   <52627>
-%! ## Same test code as above, but intended only for test statistics on Mac and
-%! ## Windows. Their trig/hyperbolic functions have huge tolerances.
+%!testif ; __have_feature__ ("LLVM_LIBCXX") || ispc ()  <52627>
+%! ## Same test code as above, but intended for test statistics with libc++ or
+%! ## on Windows.  Their trig/hyperbolic functions have huge tolerances.
 %! x = [1, -1, i, -i] .* 1e150;
 %! v = [pi/2, -pi/2, 0, -0];
 %! assert (real (asin (x)), v);
@@ -378,14 +378,14 @@ Compute the inverse hyperbolic sine for each element of @var{x}.
 
 ## Test large magnitude arguments (bug #45507)
 ## Test fails with older versions of libm, solution is to upgrade.
-%!testif ; ! ismac () && ! ispc ()   <*45507>
+%!testif ; ! __have_feature__ ("LLVM_LIBCXX") && ! ispc ()  <*45507>
 %! x = [1, -1, i, -i] .* 1e150;
 %! v = [0, 0, pi/2, -pi/2];
 %! assert (imag (asinh (x)), v);
 
-%!testif ; ismac () || ispc ()   <52627>
-%! ## Same test code as above, but intended only for test statistics on Mac and
-%! ## Windows.  Their trig/hyperbolic functions have huge tolerances.
+%!testif ; __have_feature__ ("LLVM_LIBCXX") || ispc ()  <52627>
+%! ## Same test code as above, but intended for test statistics with libc++ or
+%! ## on Windows.  Their trig/hyperbolic functions have huge tolerances.
 %! x = [1, -1, i, -i] .* 1e150;
 %! v = [0, 0, pi/2, -pi/2];
 %! assert (imag (asinh (x)), v);
