@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -44,6 +44,8 @@
 #include "ov-re-sparse.h"
 #include "ov-cx-sparse.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 template <typename ArrayType>
 static octave_value_list
 do_minmax_red_op (const octave_value& arg,
@@ -246,7 +248,7 @@ do_minmax_body (const octave_value_list& args,
 
   octave_value_list retval (nargout > 1 ? 2 : 1);
 
-  const char *func = (ismin ? "min" : "max");
+  const char *fcn = (ismin ? "min" : "max");
 
   if (nargin == 3 || nargin == 1)
     {
@@ -257,10 +259,10 @@ do_minmax_body (const octave_value_list& args,
           dim = args(2).int_value (true) - 1;
 
           if (dim < 0)
-            error ("%s: DIM must be a valid dimension", func);
+            error ("%s: DIM must be a valid dimension", fcn);
 
           if (! args(1).isempty ())
-            warning ("%s: second argument is ignored", func);
+            warning ("%s: second argument is ignored", fcn);
         }
 
       switch (arg.builtin_type ())
@@ -269,7 +271,7 @@ do_minmax_body (const octave_value_list& args,
           {
             if (arg.is_range () && (dim == -1 || dim == 1))
               {
-                Range range = arg.range_value ();
+                range<double> range = arg.range_value ();
                 if (range.numel () < 1)
                   {
                     retval(0) = arg;
@@ -281,19 +283,20 @@ do_minmax_body (const octave_value_list& args,
                     retval(0) = range.min ();
                     if (nargout > 1)
                       retval(1) = static_cast<double>
-                                  (range.inc () < 0 ? range.numel () : 1);
+                                  (range.increment () < 0 ? range.numel () : 1);
                   }
                 else
                   {
                     retval(0) = range.max ();
                     if (nargout > 1)
                       retval(1) = static_cast<double>
-                                  (range.inc () >= 0 ? range.numel () : 1);
+                                  (range.increment () >= 0 ? range.numel ()
+                                   : 1);
                   }
               }
             else if (arg.issparse ())
               retval = do_minmax_red_op<SparseMatrix> (arg, nargout, dim,
-                                                       ismin);
+                       ismin);
             else
               retval = do_minmax_red_op<NDArray> (arg, nargout, dim, ismin);
 
@@ -304,10 +307,10 @@ do_minmax_body (const octave_value_list& args,
           {
             if (arg.issparse ())
               retval = do_minmax_red_op<SparseComplexMatrix> (arg, nargout, dim,
-                                                              ismin);
+                       ismin);
             else
               retval = do_minmax_red_op<ComplexNDArray> (arg, nargout, dim,
-                                                         ismin);
+                       ismin);
           }
           break;
 
@@ -317,7 +320,7 @@ do_minmax_body (const octave_value_list& args,
 
         case btyp_float_complex:
           retval = do_minmax_red_op<FloatComplexNDArray> (arg, nargout, dim,
-                                                          ismin);
+                   ismin);
           break;
 
         case btyp_char:
@@ -329,14 +332,14 @@ do_minmax_body (const octave_value_list& args,
           retval = do_minmax_red_op<X ## NDArray> (arg, nargout, dim, ismin); \
           break;
 
-        MAKE_INT_BRANCH (int8);
-        MAKE_INT_BRANCH (int16);
-        MAKE_INT_BRANCH (int32);
-        MAKE_INT_BRANCH (int64);
-        MAKE_INT_BRANCH (uint8);
-        MAKE_INT_BRANCH (uint16);
-        MAKE_INT_BRANCH (uint32);
-        MAKE_INT_BRANCH (uint64);
+          MAKE_INT_BRANCH (int8);
+          MAKE_INT_BRANCH (int16);
+          MAKE_INT_BRANCH (int32);
+          MAKE_INT_BRANCH (int64);
+          MAKE_INT_BRANCH (uint8);
+          MAKE_INT_BRANCH (uint16);
+          MAKE_INT_BRANCH (uint32);
+          MAKE_INT_BRANCH (uint64);
 
 #undef MAKE_INT_BRANCH
 
@@ -345,7 +348,7 @@ do_minmax_body (const octave_value_list& args,
           break;
 
         default:
-          err_wrong_type_arg (func, arg);
+          err_wrong_type_arg (fcn, arg);
         }
     }
   else
@@ -382,7 +385,7 @@ do_minmax_body (const octave_value_list& args,
                  && (argy.issparse () || argy.is_scalar_type ()))
                 || (argy.issparse () && argx.is_scalar_type ()))
               retval = do_minmax_bin_op<SparseComplexMatrix> (argx, argy,
-                                                              ismin);
+                       ismin);
             else
               retval = do_minmax_bin_op<ComplexNDArray> (argx, argy, ismin);
           }
@@ -405,14 +408,14 @@ do_minmax_body (const octave_value_list& args,
           retval = do_minmax_bin_op<X ## NDArray> (argx, argy, ismin); \
           break;
 
-        MAKE_INT_BRANCH (int8);
-        MAKE_INT_BRANCH (int16);
-        MAKE_INT_BRANCH (int32);
-        MAKE_INT_BRANCH (int64);
-        MAKE_INT_BRANCH (uint8);
-        MAKE_INT_BRANCH (uint16);
-        MAKE_INT_BRANCH (uint32);
-        MAKE_INT_BRANCH (uint64);
+          MAKE_INT_BRANCH (int8);
+          MAKE_INT_BRANCH (int16);
+          MAKE_INT_BRANCH (int32);
+          MAKE_INT_BRANCH (int64);
+          MAKE_INT_BRANCH (uint8);
+          MAKE_INT_BRANCH (uint16);
+          MAKE_INT_BRANCH (uint32);
+          MAKE_INT_BRANCH (uint64);
 
 #undef MAKE_INT_BRANCH
 
@@ -422,7 +425,7 @@ do_minmax_body (const octave_value_list& args,
         //   break;
 
         default:
-          error ("%s: cannot compute %s (%s, %s)", func, func,
+          error ("%s: cannot compute %s (%s, %s)", fcn, fcn,
                  argx.type_name ().c_str (), argy.type_name ().c_str ());
         }
 
@@ -437,10 +440,10 @@ do_minmax_body (const octave_value_list& args,
 
 DEFUN (min, args, nargout,
        doc: /* -*- texinfo -*-
-@deftypefn  {} {} min (@var{x})
-@deftypefnx {} {} min (@var{x}, [], @var{dim})
-@deftypefnx {} {[@var{w}, @var{iw}] =} min (@var{x})
-@deftypefnx {} {} min (@var{x}, @var{y})
+@deftypefn  {} {@var{m} =} min (@var{x})
+@deftypefnx {} {@var{m} =} min (@var{x}, [], @var{dim})
+@deftypefnx {} {[@var{m}, @var{im}] =} min (@var{x})
+@deftypefnx {} {@var{m} =} min (@var{x}, @var{y})
 Find minimum values in the array @var{x}.
 
 For a vector argument, return the minimum value.  For a matrix argument,
@@ -659,10 +662,10 @@ the first index of the minimum value(s).  Thus,
 
 DEFUN (max, args, nargout,
        doc: /* -*- texinfo -*-
-@deftypefn  {} {} max (@var{x})
-@deftypefnx {} {} max (@var{x}, [], @var{dim})
-@deftypefnx {} {[@var{w}, @var{iw}] =} max (@var{x})
-@deftypefnx {} {} max (@var{x}, @var{y})
+@deftypefn  {} {@var{m} =} max (@var{x})
+@deftypefnx {} {@var{m} =} max (@var{x}, [], @var{dim})
+@deftypefnx {} {[@var{m}, @var{im}] =} max (@var{x})
+@deftypefnx {} {@var{m} =} max (@var{x}, @var{y})
 Find maximum values in the array @var{x}.
 
 For a vector argument, return the maximum value.  For a matrix argument,
@@ -922,7 +925,7 @@ do_cumminmax_body (const octave_value_list& args,
   if (nargin < 1 || nargin > 2)
     print_usage ();
 
-  const char *func = (ismin ? "cummin" : "cummax");
+  const char *fcn = (ismin ? "cummin" : "cummax");
 
   octave_value arg = args(0);
   int dim = -1;
@@ -931,7 +934,7 @@ do_cumminmax_body (const octave_value_list& args,
       dim = args(1).int_value (true) - 1;
 
       if (dim < 0)
-        error ("%s: DIM must be a valid dimension", func);
+        error ("%s: DIM must be a valid dimension", fcn);
     }
 
   octave_value_list retval;
@@ -944,7 +947,7 @@ do_cumminmax_body (const octave_value_list& args,
 
     case btyp_complex:
       retval = do_cumminmax_red_op<ComplexNDArray> (arg, nargout, dim,
-                                                    ismin);
+               ismin);
       break;
 
     case btyp_float:
@@ -953,7 +956,7 @@ do_cumminmax_body (const octave_value_list& args,
 
     case btyp_float_complex:
       retval = do_cumminmax_red_op<FloatComplexNDArray> (arg, nargout, dim,
-                                                         ismin);
+               ismin);
       break;
 
 #define MAKE_INT_BRANCH(X)                                                   \
@@ -975,14 +978,14 @@ do_cumminmax_body (const octave_value_list& args,
     case btyp_bool:
       {
         retval = do_cumminmax_red_op<int8NDArray> (arg, nargout, dim,
-                                                   ismin);
+                 ismin);
         if (retval.length () > 0)
           retval(0) = retval(0).bool_array_value ();
       }
       break;
 
     default:
-      err_wrong_type_arg (func, arg);
+      err_wrong_type_arg (fcn, arg);
     }
 
   return retval;
@@ -990,9 +993,9 @@ do_cumminmax_body (const octave_value_list& args,
 
 DEFUN (cummin, args, nargout,
        doc: /* -*- texinfo -*-
-@deftypefn  {} {} cummin (@var{x})
-@deftypefnx {} {} cummin (@var{x}, @var{dim})
-@deftypefnx {} {[@var{w}, @var{iw}] =} cummin (@var{x})
+@deftypefn  {} {@var{M} =} cummin (@var{x})
+@deftypefnx {} {@var{M} =} cummin (@var{x}, @var{dim})
+@deftypefnx {} {[@var{M}, @var{IM}] =} cummin (@var{x})
 Return the cumulative minimum values along dimension @var{dim}.
 
 If @var{dim} is unspecified it defaults to column-wise operation.  For
@@ -1010,10 +1013,10 @@ returned.
 
 @example
 @group
-[w, iw] = cummin ([5 4 6 2 3 1])
+[M, IM] = cummin ([5 4 6 2 3 1])
 @result{}
-w =  5  4  4  2  2  1
-iw = 1  2  2  4  4  6
+M =  5  4  4  2  2  1
+IM = 1  2  2  4  4  6
 @end group
 @end example
 
@@ -1045,9 +1048,9 @@ iw = 1  2  2  4  4  6
 
 DEFUN (cummax, args, nargout,
        doc: /* -*- texinfo -*-
-@deftypefn  {} {} cummax (@var{x})
-@deftypefnx {} {} cummax (@var{x}, @var{dim})
-@deftypefnx {} {[@var{w}, @var{iw}] =} cummax (@dots{})
+@deftypefn  {} {@var{M} =} cummax (@var{x})
+@deftypefnx {} {@var{M} =} cummax (@var{x}, @var{dim})
+@deftypefnx {} {[@var{M}, @var{IM}] =} cummax (@dots{})
 Return the cumulative maximum values along dimension @var{dim}.
 
 If @var{dim} is unspecified it defaults to column-wise operation.  For
@@ -1067,8 +1070,8 @@ returned.
 @group
 [w, iw] = cummax ([1 3 2 6 4 5])
 @result{}
-w =  1  3  3  6  6  6
-iw = 1  2  2  4  4  4
+M =  1  3  3  6  6  6
+IM = 1  2  2  4  4  4
 @end group
 @end example
 
@@ -1097,3 +1100,5 @@ iw = 1  2  2  4  4  4
 %!error cummax ()
 %!error cummax (1, 2, 3)
 */
+
+OCTAVE_END_NAMESPACE(octave)
