@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.7.3.  */
+/* A Bison parser, made by GNU Bison 3.8.2.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -53,7 +53,7 @@
 extern int octave_tex_debug;
 #endif
 /* "%code requires" blocks.  */
-#line 62 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 62 "../libinterp/corefcn/oct-tex-parser.yy"
 #include <string>
 
 #line 60 "libinterp/corefcn/oct-tex-parser.h"
@@ -87,33 +87,12 @@ extern int octave_tex_debug;
   };
   typedef enum octave_tex_tokentype octave_tex_token_kind_t;
 #endif
-/* Token kinds.  */
-#define OCTAVE_TEX_EOF 0
-#define OCTAVE_TEX_error 256
-#define OCTAVE_TEX_UNDEF 257
-#define BF 258
-#define IT 259
-#define SL 260
-#define RM 261
-#define FONTNAME 262
-#define FONTSIZE 263
-#define COLOR 264
-#define COLOR_RGB 265
-#define START 266
-#define END 267
-#define SUPER 268
-#define SUB 269
-#define CH 270
-#define NUM 271
-#define SYM 272
-#define SCRIPT 273
-#define STR 274
 
 /* Value type.  */
 #if ! defined OCTAVE_TEX_STYPE && ! defined OCTAVE_TEX_STYPE_IS_DECLARED
 union OCTAVE_TEX_STYPE
 {
-#line 65 "/home/jwe/src/octave-stable/libinterp/corefcn/oct-tex-parser.yy"
+#line 65 "../libinterp/corefcn/oct-tex-parser.yy"
 
   // Leaf symbols produced by the scanner.
   char ch;
@@ -127,7 +106,7 @@ union OCTAVE_TEX_STYPE
   octave::text_element *e_base;
   octave::text_element_list *e_list;
 
-#line 131 "libinterp/corefcn/oct-tex-parser.h"
+#line 110 "libinterp/corefcn/oct-tex-parser.h"
 
 };
 typedef union OCTAVE_TEX_STYPE OCTAVE_TEX_STYPE;
@@ -137,6 +116,8 @@ typedef union OCTAVE_TEX_STYPE OCTAVE_TEX_STYPE;
 
 
 
+
 int octave_tex_parse (octave::text_parser_tex& parser);
 
+
 #endif /* !YY_OCTAVE_TEX_LIBINTERP_COREFCN_OCT_TEX_PARSER_H_INCLUDED  */
