@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1993-2020 The Octave Project Developers
+// Copyright (C) 1993-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -48,17 +48,21 @@ set_output_prec (int prec)
   Voutput_precision = prec;
 }
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 DEFUN (output_precision, args, nargout,
        doc: /* -*- texinfo -*-
 @deftypefn  {} {@var{val} =} output_precision ()
 @deftypefnx {} {@var{old_val} =} output_precision (@var{new_val})
-@deftypefnx {} {} output_precision (@var{new_val}, "local")
+@deftypefnx {} {@var{old_val} =} output_precision (@var{new_val}, "local")
 Query or set the internal variable that specifies the minimum number of
 significant figures to display for numeric output.
 
 Note that regardless of the value set for @code{output_precision}, the
 number of digits of precision displayed is limited to 16 for double
-precision values and 7 for single precision values.
+precision values and 7 for single precision values.  Also, calls to the
+@code{format} function that change numeric display can also change the set
+value for @code{output_precision}.
 
 When called from inside a function with the @qcode{"local"} option, the
 variable is changed locally for the function and any subroutines it calls.
@@ -67,5 +71,8 @@ The original variable value is restored when exiting the function.
 @seealso{format, fixed_point_format}
 @end deftypefn */)
 {
-  return SET_INTERNAL_VARIABLE_WITH_LIMITS (output_precision, 0, 16);
+  return set_internal_variable (Voutput_precision, args, nargout,
+                                "output_precision", 0, 16);
 }
+
+OCTAVE_END_NAMESPACE(octave)
