@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2019-2021 The Octave Project Developers
+// Copyright (C) 2019-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -53,33 +53,35 @@
 #include "error.h"
 #include "ovl.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 // Coordinates of a point in C-Space (unit square mesh)
 
-typedef struct
+struct Vector2
 {
   double x, y;
-} Vector2;
+};
 
 // The integer value and the fractional value from a point in C-Space.
 // Equivalent to the cell index the point is located in and the local
 // coordinates of the point in the cell.
 
-typedef struct
+struct Cell2
 {
   double fcx, fcy;
   signed long idx, idy;
-} Cell2;
+};
 
-typedef struct
+struct Vector3
 {
   double x, y, z;
-} Vector3;
+};
 
-typedef struct
+struct Cell3
 {
   double fcx, fcy, fcz;
   signed long idx, idy, idz;
-} Cell3;
+};
 
 static inline void
 number_to_fractional (signed long *id, double *fc, const double u)
@@ -135,17 +137,18 @@ static inline bool
 is_in_definition_set2d (const Cell2 X, const octave_idx_type cols,
                         const octave_idx_type rows)
 {
- return ( (((X.idx >= 0) && (X.idx < cols-1)) ||
-           ((X.idx == cols-1) && (X.fcx == 0.0))) &&
-          (((X.idy >= 0) && (X.idy < rows-1)) ||
-           ((X.idy == rows-1) && (X.fcy == 0.0))) );
+  return ( (((X.idx >= 0) && (X.idx < cols-1)) ||
+            ((X.idx == cols-1) && (X.fcx == 0.0))) &&
+           (((X.idy >= 0) && (X.idy < rows-1)) ||
+            ((X.idy == rows-1) && (X.fcy == 0.0))) );
 }
 
 static inline Vector2
 add2d (const Cell2 X, const Vector2 Y)
 {
   Vector2 Z = {X.idx + X.fcx + Y.x,
-               X.idy + X.fcy + Y.y};
+               X.idy + X.fcy + Y.y
+              };
 
   return (Z);
 }
@@ -195,7 +198,7 @@ calculate_step_vector2d (const Cell2 X, const Vector2 V,
 static inline bool
 is_singular2d (const Vector2 V)
 {
-  return ((octave::math::isnan (V.x) || octave::math::isnan (V.y)) ||
+  return ((math::isnan (V.x) || math::isnan (V.y)) ||
           ((V.x == 0) && (V.y == 0)));
 }
 
@@ -241,7 +244,8 @@ euler2d (const octave_idx_type cols, const octave_idx_type rows,
 
       // Runge Kutta - Heun's Scheme
       const Vector2 S = {0.5 * (S0.x + S1.x),
-                         0.5 * (S0.y + S1.y)};
+                         0.5 * (S0.y + S1.y)
+                        };
       Xnxt = add2d (X0f, S);
 
       X0f = vector_to_cell2d (Xnxt);
@@ -304,7 +308,8 @@ add3d (const Cell3 X, const Vector3 Y)
 {
   Vector3 Z = {X.idx + X.fcx + Y.x,
                X.idy + X.fcy + Y.y,
-               X.idz + X.fcz + Y.z};
+               X.idz + X.fcz + Y.z
+              };
 
   return (Z);
 }
@@ -367,8 +372,7 @@ calculate_step_vector3d (const Cell3 X, const Vector3 V,
 static inline bool
 is_singular3d (const Vector3 V)
 {
-  return ((octave::math::isnan (V.x) || octave::math::isnan (V.y) ||
-           octave::math::isnan (V.z)) ||
+  return ((math::isnan (V.x) || math::isnan (V.y) || math::isnan (V.z)) ||
           ((V.x == 0) && (V.y == 0) && (V.z == 0)));
 }
 
@@ -416,7 +420,8 @@ euler3d (const octave_idx_type nx, const octave_idx_type ny, const octave_idx_ty
       // Runge Kutta - Heun's Scheme
       const Vector3 S = {0.5 * (S0.x + S1.x),
                          0.5 * (S0.y + S1.y),
-                         0.5 * (S0.z + S1.z)};
+                         0.5 * (S0.z + S1.z)
+                        };
       Xnxt = add3d (X0f, S);
 
       X0f = vector_to_cell3d (Xnxt);
@@ -505,8 +510,8 @@ streameuler3d_internal (const octave_value_list& args, const char *fcn)
 
 DEFUN (__streameuler2d__, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn {} {} __streameuler2d__ (@var{U}, @var{V}, @var{TX}, @var{TY}, @var{ZETA}, @var{XI}, @var{H}, @var{MAXNVERTS})
-Calculates the streamline in a vector field @code{[@var{U}, @var{V}]} starting
+@deftypefn {} {@var{output} =} __streameuler2d__ (@var{U}, @var{V}, @var{TX}, @var{TY}, @var{ZETA}, @var{XI}, @var{H}, @var{MAXNVERTS})
+Calculate the streamline in a vector field @code{[@var{U}, @var{V}]} starting
 from a seed point at position @code{[@var{ZETA}, @var{XI}]}.  The integrator
 used is Heun's Scheme.  The step size can be controlled by @var{H}.  The
 Jacobian matrix can be defined for each grid cell by
@@ -520,8 +525,8 @@ Jacobian matrix can be defined for each grid cell by
 
 DEFUN (__streameuler3d__, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn {} {} __streameuler3d__ (@var{U}, @var{V}, @var{W}, @var{TX}, @var{TY}, @var{TZ}, @var{ZETA}, @var{XI}, @var{RHO}, @var{H}, @var{MAXNVERTS})
-Calculates the streamline in a vector field @code{[@var{U}, @var{V}, @var{W}]}
+@deftypefn {} {@var{output} =} __streameuler3d__ (@var{U}, @var{V}, @var{W}, @var{TX}, @var{TY}, @var{TZ}, @var{ZETA}, @var{XI}, @var{RHO}, @var{H}, @var{MAXNVERTS})
+Calculate the streamline in a vector field @code{[@var{U}, @var{V}, @var{W}]}
 starting from a seed point at position
 @code{[@var{ZETA}, @var{XI}, @var{RHO}]}.  The integrator used is Heun's
 Scheme.  The step size can be controlled by @var{H}.  The Jacobian matrix can
@@ -533,3 +538,4 @@ be defined for each grid cell by @code{[@var{TX}, @var{TY}, @var{TZ}]}.
   return streameuler3d_internal (args, "__streameuler3d__");
 }
 
+OCTAVE_END_NAMESPACE(octave)
