@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2013-2022 The Octave Project Developers
+// Copyright (C) 2013-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -44,7 +44,6 @@
 #include "defun-dld.h"
 #include "error.h"
 #include "errwarn.h"
-#include "interpreter.h"
 #include "oct-map.h"
 #include "ov-int32.h"
 #include "ov.h"
@@ -55,7 +54,7 @@
 #  include <portaudio.h>
 #endif
 
-OCTAVE_NAMESPACE_BEGIN
+OCTAVE_BEGIN_NAMESPACE(octave)
 
 #if defined (HAVE_PORTAUDIO)
 
@@ -500,7 +499,8 @@ recording using those parameters.
 %! devinfo = audiodevinfo;
 %! nout = audiodevinfo (0);
 %! nin = audiodevinfo (1);
-%! ## There might be multiple devices with the same name (e.g. on Windows WDM-KS)
+%! ## There might be multiple devices with the same name
+%! ## (e.g., on Windows WDM-KS)
 %! ## Check only the first of each unique device name.
 %! [unq_out_name, idx_unique] = unique ({devinfo.output(:).Name});
 %! unq_out_id = [devinfo.output(idx_unique).ID];
@@ -518,7 +518,7 @@ recording using those parameters.
 
 enum audio_type { TYPE_INT8, TYPE_UINT8, TYPE_UINT16, TYPE_DOUBLE };
 
-class audioplayer : public octave_base_value
+class audioplayer : public octave_base_dld_value
 {
 public:
   audioplayer (void);
@@ -536,10 +536,9 @@ public:
   bool print_as_scalar (void) const { return true; }
 
   void init (void);
-  void init_fn (void);
   void set_y (const octave_value& y);
-  void set_y (octave_function *fn);
-  void set_y (std::string fn);
+  void set_y (octave_function *fcn);
+  void set_y (std::string fcn);
   Matrix& get_y (void);
   RowVector get_left (void) const;
   RowVector get_right (void) const;
@@ -564,8 +563,8 @@ public:
   octave_value get_userdata (void);
   PaStream * get_stream (void);
 
-  void playblocking (void);
   void play (void);
+  void playblocking (void);
   void pause (void);
   void resume (void);
   void stop (void);
@@ -885,7 +884,7 @@ audioplayer::~audioplayer (void)
   if (isplaying ())
     {
       warning_with_id ("Octave:audio-interrupt",
-                       "interrupting playing audioplayer");
+                       "interrupting audioplayer during playback");
       stop ();
     }
 }
@@ -903,36 +902,6 @@ audioplayer::print_raw (std::ostream& os, bool) const
   os << 0;
 }
 
-void
-audioplayer::init_fn (void)
-{
-  if (Pa_Initialize () != paNoError)
-    error ("audioplayer: initialization error");
-
-  if (Pa_GetDeviceCount () < 1)
-    error ("audioplayer: no audio devices found or available");
-
-  int device = get_id ();
-
-  if (device == -1)
-    device = Pa_GetDefaultOutputDevice ();
-
-  output_parameters.device = device;
-  output_parameters.channelCount = 2;
-  output_parameters.sampleFormat = bits_to_format (get_nbits ());
-
-  const PaDeviceInfo *device_info = Pa_GetDeviceInfo (device);
-
-  if (! device_info)
-    warning_with_id ("Octave:invalid-default-audio-device",
-                     "invalid default audio device ID = %d", device);
-
-  output_parameters.suggestedLatency
-    = (device_info ? device_info->defaultHighOutputLatency : -1);
-
-  output_parameters.hostApiSpecificStreamInfo = nullptr;
-}
-
 void
 audioplayer::init (void)
 {
@@ -1004,9 +973,9 @@ audioplayer::set_y (const octave_value& y_arg)
 }
 
 void
-audioplayer::set_y (octave_function *fn)
+audioplayer::set_y (octave_function *fcn)
 {
-  octave_callback_function = fn;
+  octave_callback_function = fcn;
   channels = 2;
   reset_end_sample ();
 }
@@ -1268,7 +1237,7 @@ audioplayer::isplaying (void)
   return (err == 1);
 }
 
-class audiorecorder : public octave_base_value
+class audiorecorder : public octave_base_dld_value
 {
 public:
   audiorecorder (void);
@@ -1557,7 +1526,7 @@ audiorecorder::~audiorecorder (void)
   if (isrecording ())
     {
       warning_with_id ("Octave:audio-interrupt",
-                       "interrupting recording audiorecorder");
+                       "interrupting audiorecorder during recording");
       stop ();
     }
 }
@@ -1656,7 +1625,9 @@ audiorecorder::get_id (void)
 void
 audiorecorder::set_channels (int channels_arg)
 {
-  assert (channels_arg == 1 || channels_arg == 2);
+  if (channels_arg != 1 && channels_arg != 2)
+    error ("audiorecorder: number of channels must be 1 or 2");
+
   channels = channels_arg;
 }
 
@@ -1910,11 +1881,10 @@ audiorecorder::get_stream (void)
 
 #endif
 
-DEFMETHOD_DLD (__recorder_audiorecorder__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_audiorecorder__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn  {} {@var{recorder} =} __recorder_audiorecorder__ (@var{fs}, @var{nbits}, @var{channels})
 @deftypefnx {} {@var{recorder} =} __recorder_audiorecorder__ (@var{fs}, @var{nbits}, @var{channels}, @var{id})
-@deftypefnx {} {@var{recorder} =} __recorder_audiorecorder__ (@var{fcn}, @dots{})
 Undocumented internal function.
 @end deftypefn */)
 {
@@ -1922,21 +1892,10 @@ Undocumented internal function.
 
 #if defined (HAVE_PORTAUDIO)
 
-  interp.mlock ();
-
   int nargin = args.length ();
 
   audiorecorder *recorder = new audiorecorder ();
 
-  if (nargin > 0)
-    {
-      bool is_function = (args(0).is_string () || args(0).is_function_handle ()
-                          || args(0).is_inline_function ());
-
-      if (is_function)
-        error ("audiorecorder: callbacks not yet implemented");
-    }
-
   if (nargin >= 3)
     {
       recorder->set_fs (args(0).int_value ());
@@ -1953,7 +1912,6 @@ Undocumented internal function.
   retval = recorder;
 
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_audiorecorder__",
@@ -1966,10 +1924,8 @@ Undocumented internal function.
 #if defined (HAVE_PORTAUDIO)
 
 static audiorecorder *
-get_recorder (interpreter& interp, const octave_value& ov)
+get_recorder (const octave_value& ov)
 {
-  interp.mlock ();
-
   const octave_base_value& rep = ov.get_rep ();
 
   octave_base_value *ncrep = const_cast<octave_base_value *> (&rep);
@@ -1983,8 +1939,8 @@ get_recorder (interpreter& interp, const octave_value& ov)
 
 #endif
 
-DEFMETHOD_DLD (__recorder_getaudiodata__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_getaudiodata__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{data} =} __recorder_getaudiodata__ (@var{recorder})
 Undocumented internal function.
 @end deftypefn */)
@@ -1992,9 +1948,8 @@ Undocumented internal function.
   octave_value retval;
 
 #if defined (HAVE_PORTAUDIO)
-  retval = get_recorder (interp, args(0))->getaudiodata ();
+  retval = get_recorder (args(0))->getaudiodata ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_getaudiodata__",
@@ -2004,8 +1959,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__recorder_get_channels__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_get_channels__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{n} =} __recorder_get_channels__ (@var{recorder})
 Undocumented internal function.
 @end deftypefn */)
@@ -2013,9 +1968,8 @@ Undocumented internal function.
   octave_value retval;
 
 #if defined (HAVE_PORTAUDIO)
-  retval = get_recorder (interp, args(0))->get_channels ();
+  retval = get_recorder (args(0))->get_channels ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_get_channels__",
@@ -2025,8 +1979,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__recorder_get_fs__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_get_fs__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{fs} =} __recorder_get_fs__ (@var{recorder})
 Undocumented internal function.
 @end deftypefn */)
@@ -2034,9 +1988,8 @@ Undocumented internal function.
   octave_value retval;
 
 #if defined (HAVE_PORTAUDIO)
-  retval = get_recorder (interp, args(0))->get_fs ();
+  retval = get_recorder (args(0))->get_fs ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_get_fs__",
@@ -2046,8 +1999,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__recorder_get_id__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_get_id__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{id} =} __recorder_get_id__ (@var{recorder})
 Undocumented internal function.
 @end deftypefn */)
@@ -2055,9 +2008,8 @@ Undocumented internal function.
   octave_value retval;
 
 #if defined (HAVE_PORTAUDIO)
-  retval = get_recorder (interp, args(0))->get_id ();
+  retval = get_recorder (args(0))->get_id ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_get_id__",
@@ -2067,8 +2019,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__recorder_get_nbits__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_get_nbits__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{nbits} =} __recorder_get_nbits__ (@var{recorder})
 Undocumented internal function.
 @end deftypefn */)
@@ -2076,9 +2028,8 @@ Undocumented internal function.
   octave_value retval;
 
 #if defined (HAVE_PORTAUDIO)
-  retval = get_recorder (interp, args(0))->get_nbits ();
+  retval = get_recorder (args(0))->get_nbits ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_get_nbits__",
@@ -2088,8 +2039,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__recorder_get_sample_number__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_get_sample_number__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{n} =} __recorder_get_sample_number__ (@var{recorder})
 Undocumented internal function.
 @end deftypefn */)
@@ -2097,9 +2048,8 @@ Undocumented internal function.
   octave_value retval;
 
 #if defined (HAVE_PORTAUDIO)
-  retval = get_recorder (interp, args(0))->get_sample_number ();
+  retval = get_recorder (args(0))->get_sample_number ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_get_sample_number__",
@@ -2109,8 +2059,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__recorder_get_tag__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_get_tag__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{tag} =} __recorder_get_tag__ (@var{recorder})
 Undocumented internal function.
 @end deftypefn */)
@@ -2118,9 +2068,8 @@ Undocumented internal function.
   octave_value retval;
 
 #if defined (HAVE_PORTAUDIO)
-  retval = get_recorder (interp, args(0))->get_tag ();
+  retval = get_recorder (args(0))->get_tag ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_get_tag__",
@@ -2130,8 +2079,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__recorder_get_total_samples__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_get_total_samples__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{n} =} __recorder_get_total_samples__ (@var{recorder})
 Undocumented internal function.
 @end deftypefn */)
@@ -2139,9 +2088,8 @@ Undocumented internal function.
   octave_value retval;
 
 #if defined (HAVE_PORTAUDIO)
-  retval = get_recorder (interp, args(0))->get_total_samples ();
+  retval = get_recorder (args(0))->get_total_samples ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_get_total_samples__",
@@ -2151,8 +2099,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__recorder_get_userdata__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_get_userdata__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{data} =} __recorder_get_userdata__ (@var{recorder})
 Undocumented internal function.
 @end deftypefn */)
@@ -2160,9 +2108,8 @@ Undocumented internal function.
   octave_value retval;
 
 #if defined (HAVE_PORTAUDIO)
-  retval = get_recorder (interp, args(0))->get_userdata ();
+  retval = get_recorder (args(0))->get_userdata ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_get_userdata__",
@@ -2172,18 +2119,17 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__recorder_isrecording__, interp, args, ,
-               doc: /* -*- texinfo -*-
-@deftypefn {} {} __recorder_isrecording__ (@var{recorder})
+DEFUN_DLD (__recorder_isrecording__, args, ,
+           doc: /* -*- texinfo -*-
+@deftypefn {} {@var{tf} =} __recorder_isrecording__ (@var{recorder})
 Undocumented internal function.
 @end deftypefn */)
 {
   octave_value retval;
 
 #if defined (HAVE_PORTAUDIO)
-  retval = get_recorder (interp, args(0))->isrecording ();
+  retval = get_recorder (args(0))->isrecording ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_isrecording__",
@@ -2193,17 +2139,16 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__recorder_pause__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_pause__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {} __recorder_pause__ (@var{recorder})
 Undocumented internal function.
 @end deftypefn */)
 {
 #if defined (HAVE_PORTAUDIO)
-  get_recorder (interp, args(0))->pause ();
+  get_recorder (args(0))->pause ();
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_pause__",
@@ -2211,18 +2156,17 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__recorder_recordblocking__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_recordblocking__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {} __recorder_recordblocking__ (@var{recorder}, @var{seconds})
 Undocumented internal function.
 @end deftypefn */)
 {
 #if defined (HAVE_PORTAUDIO)
   float seconds = args(1).float_value ();
-  get_recorder (interp, args(0))->recordblocking (seconds);
+  get_recorder (args(0))->recordblocking (seconds);
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_recordblocking__",
@@ -2230,15 +2174,15 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__recorder_record__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_record__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn  {} {} __recorder_record__ (@var{recorder})
 @deftypefnx {} {} __recorder_record__ (@var{recorder}, @var{seconds})
 Undocumented internal function.
 @end deftypefn */)
 {
 #if defined (HAVE_PORTAUDIO)
-  audiorecorder *recorder = get_recorder (interp, args(0));
+  audiorecorder *recorder = get_recorder (args(0));
 
   if (args.length () == 2)
     recorder->set_end_sample (args(1).int_value () * recorder->get_fs ());
@@ -2246,7 +2190,6 @@ Undocumented internal function.
   recorder->record ();
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_record__",
@@ -2254,18 +2197,17 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__recorder_resume__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_resume__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {} __recorder_resume__ (@var{recorder})
 Undocumented internal function.
 @end deftypefn */)
 {
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 1)
-    get_recorder (interp, args(0))->resume ();
+    get_recorder (args(0))->resume ();
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_resume__",
@@ -2273,18 +2215,17 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__recorder_set_fs__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_set_fs__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {} __recorder_set_fs__ (@var{recorder}, @var{fs})
 Undocumented internal function.
 @end deftypefn */)
 {
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 2)
-    get_recorder (interp, args(0))->set_fs (args(1).int_value ());
+    get_recorder (args(0))->set_fs (args(1).int_value ());
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_set_fs__",
@@ -2292,18 +2233,17 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__recorder_set_tag__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_set_tag__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {} __recorder_set_tag__ (@var{recorder}, @var{tag})
 Undocumented internal function.
 @end deftypefn */)
 {
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 2)
-    get_recorder (interp, args(0))->set_tag (args(1).char_matrix_value ());
+    get_recorder (args(0))->set_tag (args(1).char_matrix_value ());
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_set_tag__",
@@ -2311,18 +2251,17 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__recorder_set_userdata__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_set_userdata__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {} __recorder_set_userdata__ (@var{recorder}, @var{data})
 Undocumented internal function.
 @end deftypefn */)
 {
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 2)
-    get_recorder (interp, args(0))->set_userdata (args(1));
+    get_recorder (args(0))->set_userdata (args(1));
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_set_userdata__",
@@ -2330,18 +2269,17 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__recorder_stop__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__recorder_stop__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {} __recorder_stop__ (@var{recorder})
 Undocumented internal function.
 @end deftypefn */)
 {
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 1)
-    get_recorder (interp, args(0))->stop ();
+    get_recorder (args(0))->stop ();
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__recorder_stop__",
@@ -2349,8 +2287,8 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__player_audioplayer__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_audioplayer__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn  {} {@var{player} =} __player_audioplayer__ (@var{y}, @var{fs})
 @deftypefnx {} {@var{player} =} __player_audioplayer__ (@var{y}, @var{fs}, @var{nbits})
 @deftypefnx {} {@var{player} =} __player_audioplayer__ (@var{y}, @var{fs}, @var{nbits}, @var{id})
@@ -2360,16 +2298,9 @@ Undocumented internal function.
   octave_value retval;
 
 #if defined (HAVE_PORTAUDIO)
-  interp.mlock ();
 
   audioplayer *recorder = new audioplayer ();
 
-  bool is_function = (args(0).is_string () || args(0).is_function_handle ()
-                      || args(0).is_inline_function ());
-
-  if (is_function)
-    error ("audioplayer: callbacks not yet implemented");
-
   recorder->set_y (args(0));
   recorder->set_fs (args(1).int_value ());
 
@@ -2393,14 +2324,10 @@ Undocumented internal function.
         }
     }
 
-  if (is_function)
-    recorder->init_fn ();
-  else
-    recorder->init ();
+  recorder->init ();
 
   retval = recorder;
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_audioplayer__",
@@ -2413,10 +2340,8 @@ Undocumented internal function.
 #if defined (HAVE_PORTAUDIO)
 
 static audioplayer *
-get_player (interpreter& interp, const octave_value& ov)
+get_player (const octave_value& ov)
 {
-  interp.mlock ();
-
   const octave_base_value& rep = ov.get_rep ();
 
   octave_base_value *ncrep = const_cast<octave_base_value *> (&rep);
@@ -2430,8 +2355,8 @@ get_player (interpreter& interp, const octave_value& ov)
 
 #endif
 
-DEFMETHOD_DLD (__player_get_channels__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_get_channels__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{n} =} __player_get_channels__ (@var{player})
 Undocumented internal function.
 @end deftypefn */)
@@ -2440,9 +2365,8 @@ Undocumented internal function.
 
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 1)
-    retval = get_player (interp, args(0))->get_channels ();
+    retval = get_player (args(0))->get_channels ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_get_channels__",
@@ -2452,8 +2376,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__player_get_fs__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_get_fs__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{fs} =} __player_get_fs__ (@var{player})
 Undocumented internal function.
 @end deftypefn */)
@@ -2462,9 +2386,8 @@ Undocumented internal function.
 
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 1)
-    retval = get_player (interp, args(0))->get_fs ();
+    retval = get_player (args(0))->get_fs ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_get_fs__",
@@ -2474,8 +2397,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__player_get_id__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_get_id__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{id} =} __player_get_id__ (@var{player})
 Undocumented internal function.
 @end deftypefn */)
@@ -2484,9 +2407,8 @@ Undocumented internal function.
 
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 1)
-    retval = get_player (interp, args(0))->get_id ();
+    retval = get_player (args(0))->get_id ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_get_id__",
@@ -2496,8 +2418,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__player_get_nbits__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_get_nbits__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{nbits} =} __player_get_nbits__ (@var{player})
 Undocumented internal function.
 @end deftypefn */)
@@ -2506,9 +2428,8 @@ Undocumented internal function.
 
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 1)
-    retval = get_player (interp, args(0))->get_nbits ();
+    retval = get_player (args(0))->get_nbits ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_get_nbits__",
@@ -2518,8 +2439,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__player_get_sample_number__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_get_sample_number__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{n} =} __player_get_sample_number__ (@var{player})
 Undocumented internal function.
 @end deftypefn */)
@@ -2528,9 +2449,8 @@ Undocumented internal function.
 
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 1)
-    retval = get_player (interp, args(0))->get_sample_number ();
+    retval = get_player (args(0))->get_sample_number ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_get_sample_number__",
@@ -2540,8 +2460,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__player_get_tag__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_get_tag__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{tag} =} __player_get_tag__ (@var{player})
 Undocumented internal function.
 @end deftypefn */)
@@ -2550,9 +2470,8 @@ Undocumented internal function.
 
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 1)
-    retval = get_player (interp, args(0))->get_tag ();
+    retval = get_player (args(0))->get_tag ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_get_tag__",
@@ -2562,8 +2481,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__player_get_total_samples__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_get_total_samples__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{n} =} __player_get_total_samples__ (@var{player})
 Undocumented internal function.
 @end deftypefn */)
@@ -2572,9 +2491,8 @@ Undocumented internal function.
 
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 1)
-    retval = get_player (interp, args(0))->get_total_samples ();
+    retval = get_player (args(0))->get_total_samples ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_get_total_samples__",
@@ -2584,8 +2502,8 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__player_get_userdata__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_get_userdata__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {@var{data} =} __player_get_userdata__ (@var{player})
 Undocumented internal function.
 @end deftypefn */)
@@ -2594,9 +2512,8 @@ Undocumented internal function.
 
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 1)
-    retval = get_player (interp, args(0))->get_userdata ();
+    retval = get_player (args(0))->get_userdata ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_get_userdata__",
@@ -2606,9 +2523,9 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__player_isplaying__, interp, args, ,
-               doc: /* -*- texinfo -*-
-@deftypefn {} {} __player_isplaying__ (@var{player})
+DEFUN_DLD (__player_isplaying__, args, ,
+           doc: /* -*- texinfo -*-
+@deftypefn {} {@var{tf} =} __player_isplaying__ (@var{player})
 Undocumented internal function.
 @end deftypefn */)
 {
@@ -2616,9 +2533,8 @@ Undocumented internal function.
 
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 1)
-    retval = get_player (interp, args(0))->isplaying ();
+    retval = get_player (args(0))->isplaying ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_isplaying__",
@@ -2628,18 +2544,17 @@ Undocumented internal function.
   return retval;
 }
 
-DEFMETHOD_DLD (__player_pause__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_pause__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {} __player_pause__ (@var{player})
 Undocumented internal function.
 @end deftypefn */)
 {
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 1)
-    get_player (interp, args(0))->pause ();
+    get_player (args(0))->pause ();
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_pause__",
@@ -2647,8 +2562,8 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__player_playblocking__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_playblocking__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn  {} {} __player_playblocking__ (@var{player})
 @deftypefnx {} {} __player_playblocking__ (@var{player}, @var{start})
 @deftypefnx {} {} __player_playblocking__ (@var{player}, [@var{start}, @var{end}])
@@ -2657,7 +2572,7 @@ Undocumented internal function.
 {
 #if defined (HAVE_PORTAUDIO)
 
-  audioplayer *player = get_player (interp, args(0));
+  audioplayer *player = get_player (args(0));
 
   if (args.length () == 1)
     {
@@ -2694,7 +2609,6 @@ Undocumented internal function.
 
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_playblocking__",
@@ -2702,8 +2616,8 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__player_play__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_play__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn  {} {} __player_play__ (@var{player})
 @deftypefnx {} {} __player_play__ (@var{player}, @var{start})
 @deftypefnx {} {} __player_play__ (@var{player}, [@var{start}, @var{end}])
@@ -2714,11 +2628,11 @@ Undocumented internal function.
 
   if (args.length () == 1)
     {
-      get_player (interp, args(0))->play ();
+      get_player (args(0))->play ();
     }
   else if (args.length () == 2)
     {
-      audioplayer *player = get_player (interp, args(0));
+      audioplayer *player = get_player (args(0));
 
       if (args(1).is_matrix_type ())
         {
@@ -2749,7 +2663,6 @@ Undocumented internal function.
 
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_play__",
@@ -2757,18 +2670,17 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__player_resume__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_resume__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {} __player_resume__ (@var{player})
 Undocumented internal function.
 @end deftypefn */)
 {
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 1)
-    get_player (interp, args(0))->resume ();
+    get_player (args(0))->resume ();
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_resume__",
@@ -2776,18 +2688,17 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__player_set_fs__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_set_fs__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {} __player_set_fs__ (@var{player}, @var{fs})
 Undocumented internal function.
 @end deftypefn */)
 {
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 2)
-    get_player (interp, args(0))->set_fs (args(1).int_value ());
+    get_player (args(0))->set_fs (args(1).int_value ());
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_set_fs__",
@@ -2795,18 +2706,17 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__player_set_tag__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_set_tag__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {} __player_set_tag__ (@var{player}, @var{tag})
 Undocumented internal function.
 @end deftypefn */)
 {
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 2)
-    get_player (interp, args(0))->set_tag (args(1).char_matrix_value ());
+    get_player (args(0))->set_tag (args(1).char_matrix_value ());
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_set_tag__",
@@ -2814,18 +2724,17 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__player_set_userdata__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_set_userdata__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {} __player_set_userdata__ (@var{player}, @var{data})
 Undocumented internal function.
 @end deftypefn */)
 {
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 2)
-    get_player (interp, args(0))->set_userdata (args(1));
+    get_player (args(0))->set_userdata (args(1));
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_set_userdata__",
@@ -2833,18 +2742,17 @@ Undocumented internal function.
 #endif
 }
 
-DEFMETHOD_DLD (__player_stop__, interp, args, ,
-               doc: /* -*- texinfo -*-
+DEFUN_DLD (__player_stop__, args, ,
+           doc: /* -*- texinfo -*-
 @deftypefn {} {} __player_stop__ (@var{player})
 Undocumented internal function.
 @end deftypefn */)
 {
 #if defined (HAVE_PORTAUDIO)
   if (args.length () == 1)
-    get_player (interp, args(0))->stop ();
+    get_player (args(0))->stop ();
   return ovl ();
 #else
-  octave_unused_parameter (interp);
   octave_unused_parameter (args);
 
   err_disabled_feature ("__player_stop__",
@@ -2852,4 +2760,4 @@ Undocumented internal function.
 #endif
 }
 
-OCTAVE_NAMESPACE_END
+OCTAVE_END_NAMESPACE(octave)
