@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2020 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -38,12 +38,12 @@
 class octave_value;
 class octave_value_list;
 
-namespace octave
-{
-  class tree_evaluator;
-  class interpreter;
-  class jit_type;
-}
+OCTAVE_BEGIN_NAMESPACE(octave)
+
+class tree_evaluator;
+class interpreter;
+
+OCTAVE_END_NAMESPACE(octave)
 
 // Builtin functions.
 
@@ -53,8 +53,8 @@ octave_builtin : public octave_function
 {
 public:
 
-  octave_builtin (void) : octave_function (), f (nullptr), m (nullptr),
-                          file (), jtype (nullptr)
+  octave_builtin (void)
+    : octave_function (), m_fcn (nullptr), m_meth (nullptr), m_file ()
   { }
 
   typedef octave_value_list (*meth) (octave::interpreter&,
@@ -64,22 +64,22 @@ public:
 
   octave_builtin (fcn ff, const std::string& nm = "",
                   const std::string& ds = "")
-    : octave_function (nm, ds), f (ff), m (nullptr), file (), jtype (nullptr)
+    : octave_function (nm, ds), m_fcn (ff), m_meth (nullptr), m_file ()
   { }
 
   octave_builtin (meth mm, const std::string& nm = "",
                   const std::string& ds = "")
-    : octave_function (nm, ds), f (nullptr), m (mm), file (), jtype (nullptr)
+    : octave_function (nm, ds), m_fcn (nullptr), m_meth (mm), m_file ()
   { }
 
   octave_builtin (fcn ff, const std::string& nm, const std::string& fnm,
                   const std::string& ds)
-    : octave_function (nm, ds), f (ff), m (nullptr), file (fnm), jtype (nullptr)
+    : octave_function (nm, ds), m_fcn (ff), m_meth (nullptr), m_file (fnm)
   { }
 
   octave_builtin (meth mm, const std::string& nm, const std::string& fnm,
                   const std::string& ds)
-    : octave_function (nm, ds), f (nullptr), m (mm), file (fnm), jtype (nullptr)
+    : octave_function (nm, ds), m_fcn (nullptr), m_meth (mm), m_file (fnm)
   { }
 
   // No copying!
@@ -90,7 +90,7 @@ public:
 
   ~octave_builtin (void) = default;
 
-  std::string src_file_name (void) const { return file; }
+  std::string src_file_name (void) const { return m_file; }
 
   octave_function * function_value (bool = false) { return this; }
 
@@ -100,10 +100,6 @@ public:
   execute (octave::tree_evaluator& tw, int nargout = 0,
            const octave_value_list& args = octave_value_list ());
 
-  octave::jit_type * to_jit (void) const;
-
-  void stash_jit (octave::jit_type& type);
-
   fcn function (void) const;
 
   meth method (void) const;
@@ -115,17 +111,14 @@ public:
 protected:
 
   // A pointer to the actual function.
-  fcn f;
-  meth m;
+  fcn m_fcn;
+  meth m_meth;
 
   // The name of the file where this function was defined.
-  std::string file;
+  std::string m_file;
 
   // The types this function has been declared to handle (if any).
-  std::set<std::string> dispatch_classes;
-
-  // A pointer to the jit type that represents the function.
-  octave::jit_type *jtype;
+  std::set<std::string> m_dispatch_classes;
 
 private:
 
