@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2012-2022 The Octave Project Developers
+// Copyright (C) 2012-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -140,7 +140,8 @@ octave_classdef::subsref (const std::string& type,
         }
     }
 
-  retval = m_object.subsref (type, idx, 1, skip, octave::cdef_class (), auto_add);
+  retval = m_object.subsref (type, idx, 1, skip,
+                             octave::cdef_class (), auto_add);
 
   if (type.length () > skip && idx.size () > skip)
     retval = retval(0).next_subsref (1, type, idx, skip);
@@ -254,13 +255,13 @@ octave_classdef::xnumel (const octave_value_list& idx)
 
           // Temporarily set lvalue list of current statement to NULL, to avoid
           // using that list for the execution of the method "numel"
-          octave::interpreter& interp = octave::__get_interpreter__ ("octave_classdef::xnumel");
+          octave::interpreter& interp = octave::__get_interpreter__ ();
           octave::tree_evaluator& tw = interp.get_evaluator();
 
           octave::unwind_action act ([&tw] (const std::list<octave::octave_lvalue> *lvl)
-                            {
-                              tw.set_lvalue_list (lvl);
-                            }, tw.lvalue_list ());
+          {
+            tw.set_lvalue_list (lvl);
+          }, tw.lvalue_list ());
           tw.set_lvalue_list (nullptr);
 
           octave_value_list lv = meth.execute (args, 1, true, "numel");
@@ -472,8 +473,8 @@ std::string octave_classdef_meta::file_name (void) const
 
 octave_value_list
 octave_classdef_superclass_ref::execute (octave::tree_evaluator& tw,
-                                         int nargout,
-                                         const octave_value_list& idx)
+    int nargout,
+    const octave_value_list& idx)
 {
   octave_value_list retval;
 
@@ -578,7 +579,7 @@ octave_classdef_superclass_ref::execute (octave::tree_evaluator& tw,
 }
 
 bool octave_classdef_superclass_ref::is_constructed_object (octave::tree_evaluator& tw,
-                                                            const std::string& nm)
+    const std::string& nm)
 {
   octave_function *of = tw.current_function ();
 
@@ -598,26 +599,26 @@ bool octave_classdef_superclass_ref::is_constructed_object (octave::tree_evaluat
   return false;
 }
 
-OCTAVE_NAMESPACE_BEGIN
+OCTAVE_BEGIN_NAMESPACE(octave)
 
 DEFUN (__meta_get_package__, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn {} {} __meta_get_package__ ()
+@deftypefn {} {@var{pkg} =} __meta_get_package__ (@var{pkg_name})
 Undocumented internal function.
 @end deftypefn */)
 {
   if (args.length () != 1)
     print_usage ();
 
-  std::string cname = args(0).xstring_value ("PACKAGE_NAME must be a string");
+  std::string cname = args(0).xstring_value ("PKG_NAME must be a string");
 
   return to_ov (lookup_package (cname));
 }
 
 DEFUN (metaclass, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn {} {} metaclass (obj)
-Returns the meta.class object corresponding to the class of @var{obj}.
+@deftypefn {} {@var{metaclass_obj} =} metaclass (obj)
+Return the meta.class object corresponding to the class of @var{obj}.
 @end deftypefn */)
 {
   if (args.length () != 1)
@@ -635,17 +636,17 @@ Returns the meta.class object corresponding to the class of @var{obj}.
 
 DEFUN (properties, args, nargout,
        doc: /* -*- texinfo -*-
-@deftypefn  {} {} properties (@var{class_name})
-@deftypefnx {} {} properties (@var{obj})
-@deftypefnx {} {@var{plist} =} properties (@dots{})
-Return or display the public properties for the named class
-@var{class_name} or classdef object @var{obj}.
+@deftypefn  {} {} properties (@var{obj})
+@deftypefnx {} {} properties (@var{class_name})
+@deftypefnx {} {@var{proplist} =} properties (@dots{})
+Display or return the public properties for the classdef object @var{obj} or
+the named class @var{class_name}.
 
-If an output value is requested, return the list of property names in a
-cell array.
+If an output value is requested, return the list of property names in a cell
+array.
 
-Programming Note: Property names are returned if the @code{GetAccess}
-attribute is public and if the @code{Hidden} attribute is false.
+Programming Note: Property names are returned if the @code{GetAccess} attribute
+is public and if the @code{Hidden} attribute is false.
 @seealso{methods}
 @end deftypefn */)
 {
@@ -721,11 +722,9 @@ attribute is public and if the @code{Hidden} attribute is false.
 
 DEFMETHOD (__methods__, interp, args, ,
            doc: /* -*- texinfo -*-
-@deftypefn  {} {} __methods__ (@var{x})
-@deftypefnx {} {} __methods__ ("classname")
-Internal function.
-
-Implements @code{methods} for Octave class objects and classnames.
+@deftypefn  {} {@var{mtds} =} __methods__ (@var{obj})
+@deftypefnx {} {@var{mtds} =} __methods__ ("classname")
+Implement @code{methods} for Octave class objects and classnames.
 @seealso{methods}
 @end deftypefn */)
 {
@@ -773,10 +772,5 @@ Implements @code{methods} for Octave class objects and classnames.
   return ovl (Cell (sv));
 }
 
-OCTAVE_NAMESPACE_END
+OCTAVE_END_NAMESPACE(octave)
 
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
