@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2008-2021 The Octave Project Developers
+// Copyright (C) 2008-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -49,8 +49,8 @@ octave_base_value::type_conv_info
 octave_null_matrix::numeric_conversion_function (void) const
 {
   return octave_base_value::type_conv_info
-           (default_null_matrix_numeric_conversion_function,
-            octave_matrix::static_type_id ());
+         (default_null_matrix_numeric_conversion_function,
+          octave_matrix::static_type_id ());
 }
 
 DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_null_str, "null_string", "char");
@@ -70,8 +70,8 @@ octave_base_value::type_conv_info
 octave_null_str::numeric_conversion_function (void) const
 {
   return octave_base_value::type_conv_info
-          (default_null_str_numeric_conversion_function,
-           octave_char_matrix_str::static_type_id ());
+         (default_null_str_numeric_conversion_function,
+          octave_char_matrix_str::static_type_id ());
 }
 
 DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_null_sq_str, "null_sq_string",
@@ -92,13 +92,15 @@ octave_base_value::type_conv_info
 octave_null_sq_str::numeric_conversion_function (void) const
 {
   return octave_base_value::type_conv_info
-           (default_null_sq_str_numeric_conversion_function,
-            octave_char_matrix_sq_str::static_type_id ());
+         (default_null_sq_str_numeric_conversion_function,
+          octave_char_matrix_sq_str::static_type_id ());
 }
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 DEFUN (isnull, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn {} {} isnull (@var{x})
+@deftypefn {} {@var{tf} =} isnull (@var{x})
 Return true if @var{x} is a special null matrix, string, or single quoted
 string.
 
@@ -155,3 +157,5 @@ str(7:end) = ""                # indexed deletion
 %! x = [];
 %! assert (isnull (x), false);
 */
+
+OCTAVE_END_NAMESPACE(octave)
