@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 1996-2017 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
-
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1996-2023 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if ! defined (octave_ov_struct_h)
 #define octave_ov_struct_h 1
@@ -40,8 +43,6 @@ along with Octave; see the file COPYING.  If not, see
 
 class octave_value_list;
 
-class tree_walker;
-
 // Data structures.
 
 class
@@ -50,20 +51,22 @@ octave_struct : public octave_base_value
 public:
 
   octave_struct (void)
-    : octave_base_value (), map () { }
+    : octave_base_value (), m_map () { }
 
   octave_struct (const octave_map& m)
-    : octave_base_value (), map (m) { }
+    : octave_base_value (), m_map (m) { }
 
   octave_struct (const octave_struct& s)
-    : octave_base_value (), map (s.map) { }
+    : octave_base_value (), m_map (s.m_map) { }
 
-  ~octave_struct (void) { }
+  ~octave_struct (void) = default;
 
-  octave_base_value *clone (void) const { return new octave_struct (*this); }
-  octave_base_value *empty_clone (void) const { return new octave_struct (); }
+  octave_base_value * clone (void) const { return new octave_struct (*this); }
+  octave_base_value * empty_clone (void) const { return new octave_struct (); }
 
-  octave_base_value *try_narrowing_conversion (void);
+  void break_closure_cycles (const std::shared_ptr<octave::stack_frame>& frame);
+
+  octave_base_value * try_narrowing_conversion (void);
 
   Cell dotref (const octave_value_list& idx, bool auto_add = false);
 
@@ -88,44 +91,47 @@ public:
                          const std::list<octave_value_list>& idx,
                          const octave_value& rhs);
 
-  octave_value squeeze (void) const { return map.squeeze (); }
+  octave_value squeeze (void) const { return m_map.squeeze (); }
 
   octave_value permute (const Array<int>& vec, bool inv = false) const
-  { return map.permute (vec, inv); }
+  { return m_map.permute (vec, inv); }
 
   octave_value do_index_op (const octave_value_list& idx,
                             bool resize_ok = false);
 
-  dim_vector dims (void) const { return map.dims (); }
+  dim_vector dims (void) const { return m_map.dims (); }
 
-  size_t byte_size (void) const;
+  std::size_t byte_size (void) const;
 
   // This is the number of elements in each field.  The total number
   // of elements is numel () * nfields ().
   octave_idx_type numel (void) const
   {
-    return map.numel ();
+    return m_map.numel ();
   }
 
-  octave_idx_type nfields (void) const { return map.nfields (); }
+  octave_idx_type nfields (void) const { return m_map.nfields (); }
 
   octave_value reshape (const dim_vector& new_dims) const
-  { return map.reshape (new_dims); }
+  { return m_map.reshape (new_dims); }
 
   octave_value resize (const dim_vector& dv, bool fill = false) const
-  { octave_map tmap = map; tmap.resize (dv, fill); return tmap; }
+  { octave_map tmap = m_map; tmap.resize (dv, fill); return tmap; }
 
   bool is_defined (void) const { return true; }
 
   bool is_constant (void) const { return true; }
 
-  bool is_map (void) const { return true; }
+  bool isstruct (void) const { return true; }
 
   builtin_type_t builtin_type (void) const { return btyp_struct; }
 
-  octave_map map_value (void) const { return map; }
+  octave_map map_value (void) const { return m_map; }
 
-  string_vector map_keys (void) const { return map.fieldnames (); }
+  string_vector map_keys (void) const { return m_map.fieldnames (); }
+
+  bool isfield (const std::string& field_name) const
+  { return m_map.isfield (field_name); }
 
   void print (std::ostream& os, bool pr_as_read_syntax = false);
 
@@ -133,11 +139,14 @@ public:
 
   bool print_name_tag (std::ostream& os, const std::string& name) const;
 
+  std::string edit_display (const float_display_format& fmt,
+                            octave_idx_type i, octave_idx_type j) const;
+
   bool save_ascii (std::ostream& os);
 
   bool load_ascii (std::istream& is);
 
-  bool save_binary (std::ostream& os, bool& save_as_floats);
+  bool save_binary (std::ostream& os, bool save_as_floats);
 
   bool load_binary (std::istream& is, bool swap,
                     octave::mach_info::float_format fmt);
@@ -146,7 +155,7 @@ public:
 
   bool load_hdf5 (octave_hdf5_id loc_id, const char *name);
 
-  mxArray *as_mxArray (void) const;
+  mxArray * as_mxArray (bool interleaved) const;
 
   octave_value
   fast_elem_extract (octave_idx_type n) const;
@@ -157,7 +166,7 @@ public:
 protected:
 
   // The associative array used to manage the structure data.
-  octave_map map;
+  octave_map m_map;
 
 private:
 
@@ -170,21 +179,26 @@ octave_scalar_struct : public octave_base_value
 public:
 
   octave_scalar_struct (void)
-    : octave_base_value (), map () { }
+    : octave_base_value (), m_map () { }
 
   octave_scalar_struct (const octave_scalar_map& m)
-    : octave_base_value (), map (m) { }
+    : octave_base_value (), m_map (m) { }
+
+  octave_scalar_struct (const std::map<std::string, octave_value>& m)
+    : octave_base_value (), m_map (m) { }
 
   octave_scalar_struct (const octave_scalar_struct& s)
-    : octave_base_value (), map (s.map) { }
+    : octave_base_value (), m_map (s.m_map) { }
 
-  ~octave_scalar_struct (void) { }
+  ~octave_scalar_struct (void) = default;
 
-  octave_base_value *clone (void) const
+  octave_base_value * clone (void) const
   { return new octave_scalar_struct (*this); }
-  octave_base_value *empty_clone (void) const
+  octave_base_value * empty_clone (void) const
   { return new octave_scalar_struct (); }
 
+  void break_closure_cycles (const std::shared_ptr<octave::stack_frame>& frame);
+
   octave_value dotref (const octave_value_list& idx, bool auto_add = false);
 
   octave_value subsref (const std::string& type,
@@ -204,17 +218,17 @@ public:
                          const std::list<octave_value_list>& idx,
                          const octave_value& rhs);
 
-  octave_value squeeze (void) const { return map; }
+  octave_value squeeze (void) const { return m_map; }
 
   octave_value permute (const Array<int>& vec, bool inv = false) const
-  { return octave_map (map).permute (vec, inv); }
+  { return octave_map (m_map).permute (vec, inv); }
 
   octave_value do_index_op (const octave_value_list& idx,
                             bool resize_ok = false);
 
   dim_vector dims (void) const { static dim_vector dv (1, 1); return dv; }
 
-  size_t byte_size (void) const;
+  std::size_t byte_size (void) const;
 
   // This is the number of elements in each field.  The total number
   // of elements is numel () * nfields ().
@@ -223,27 +237,30 @@ public:
     return 1;
   }
 
-  octave_idx_type nfields (void) const { return map.nfields (); }
+  octave_idx_type nfields (void) const { return m_map.nfields (); }
 
   octave_value reshape (const dim_vector& new_dims) const
-  { return octave_map (map).reshape (new_dims); }
+  { return octave_map (m_map).reshape (new_dims); }
 
   octave_value resize (const dim_vector& dv, bool fill = false) const
-  { octave_map tmap = map; tmap.resize (dv, fill); return tmap; }
+  { octave_map tmap = m_map; tmap.resize (dv, fill); return tmap; }
 
   bool is_defined (void) const { return true; }
 
   bool is_constant (void) const { return true; }
 
-  bool is_map (void) const { return true; }
+  bool isstruct (void) const { return true; }
 
   builtin_type_t builtin_type (void) const { return btyp_struct; }
 
-  octave_map map_value (void) const { return map; }
+  octave_map map_value (void) const { return m_map; }
 
-  octave_scalar_map scalar_map_value (void) const { return map; }
+  octave_scalar_map scalar_map_value (void) const { return m_map; }
 
-  string_vector map_keys (void) const { return map.fieldnames (); }
+  string_vector map_keys (void) const { return m_map.fieldnames (); }
+
+  bool isfield (const std::string& field_name) const
+  { return m_map.isfield (field_name); }
 
   void print (std::ostream& os, bool pr_as_read_syntax = false);
 
@@ -251,11 +268,14 @@ public:
 
   bool print_name_tag (std::ostream& os, const std::string& name) const;
 
+  std::string edit_display (const float_display_format& fmt,
+                            octave_idx_type i, octave_idx_type j) const;
+
   bool save_ascii (std::ostream& os);
 
   bool load_ascii (std::istream& is);
 
-  bool save_binary (std::ostream& os, bool& save_as_floats);
+  bool save_binary (std::ostream& os, bool save_as_floats);
 
   bool load_binary (std::istream& is, bool swap,
                     octave::mach_info::float_format fmt);
@@ -264,14 +284,14 @@ public:
 
   bool load_hdf5 (octave_hdf5_id loc_id, const char *name);
 
-  mxArray *as_mxArray (void) const;
+  mxArray * as_mxArray (bool interleaved) const;
 
   bool fast_elem_insert_self (void *where, builtin_type_t btyp) const;
 
 protected:
 
   // The associative array used to manage the structure data.
-  octave_scalar_map map;
+  octave_scalar_map m_map;
 
 private:
 
