@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2007-2022 The Octave Project Developers
+// Copyright (C) 2007-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -43,7 +43,7 @@
 #include "symtab.h"
 #include "parse.h"
 
-OCTAVE_NAMESPACE_BEGIN
+OCTAVE_BEGIN_NAMESPACE(octave)
 
 //! Default unary class operator.
 //!
@@ -55,9 +55,9 @@ oct_unop_default (const octave_value& a, const std::string& opname)
 {
   std::string class_name = a.class_name ();
 
-  octave_value meth
-    = octave::__get_symbol_table__ ("oct_unop_" + opname)
-      .find_method (opname, class_name);
+  octave::symbol_table& symtab = octave::__get_symbol_table__ ();
+
+  octave_value meth = symtab.find_method (opname, class_name);
 
   if (meth.is_defined ())
     {
@@ -140,8 +140,7 @@ static octave_value
 oct_binop_default (const octave_value& a1, const octave_value& a2,
                    const std::string& opname)
 {
-  octave::symbol_table& symtab
-    = octave::__get_symbol_table__ ("oct_binop_" + opname);
+  octave::symbol_table& symtab = octave::__get_symbol_table__ ();
 
   // Dispatch to first (leftmost) operand by default.
   std::string dispatch_type = a1.class_name ();
@@ -225,4 +224,4 @@ install_class_ops (octave::type_info& ti)
   ti.install_binary_class_op (octave_value::op_el_or,   oct_binop_or);
 }
 
-OCTAVE_NAMESPACE_END
+OCTAVE_END_NAMESPACE(octave)
