@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -44,6 +44,8 @@
 #include "xdiv.h"
 #include "xpow.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 // scalar by complex matrix ops.
 
 DEFNDBINOP_OP (add, float_scalar, float_complex_matrix, float_scalar,
@@ -98,7 +100,7 @@ DEFNDCMPLXCMPOP_FN (ne, float_scalar, float_complex_matrix, float_scalar,
 DEFNDBINOP_OP (el_mul, float_scalar, float_complex_matrix, float_scalar,
                float_complex_array, *)
 DEFNDBINOP_FN (el_div, float_scalar, float_complex_matrix, float_scalar,
-               float_complex_array, x_el_div)
+               float_complex_array, elem_xdiv)
 DEFNDBINOP_FN (el_pow, float_scalar, float_complex_matrix, float_scalar,
                float_complex_array, elem_xpow)
 
@@ -131,7 +133,7 @@ DEFCONV (float_complex_matrix_conv, float_scalar, float_complex_matrix)
   const octave_float_scalar& v = dynamic_cast<const octave_float_scalar&> (a);
 
   return new octave_float_complex_matrix (FloatComplexMatrix
-                                            (v.float_matrix_value ()));
+                                          (v.float_matrix_value ()));
 }
 
 void
@@ -186,3 +188,5 @@ install_fs_fcm_ops (octave::type_info& ti)
   INSTALL_WIDENOP_TI (ti, octave_float_scalar, octave_float_complex_matrix,
                       float_complex_matrix_conv);
 }
+
+OCTAVE_END_NAMESPACE(octave)
