@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -38,6 +38,8 @@
 #include "xdiv.h"
 #include "xpow.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 // matrix unary ops.
 
 DEFNDUNOP_OP (not, matrix, array, !)
@@ -223,3 +225,5 @@ install_m_m_ops (octave::type_info& ti)
   INSTALL_ASSIGNOP_TI (ti, op_el_div_eq, octave_matrix, octave_matrix,
                        assign_el_div);
 }
+
+OCTAVE_END_NAMESPACE(octave)
