@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1998-2021 The Octave Project Developers
+// Copyright (C) 1998-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -39,6 +39,8 @@
 #include "ov-re-sparse.h"
 #include "ov-cx-sparse.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 // sparse matrix by sparse complex matrix ops.
 
 DEFBINOP_OP (add, sparse_matrix, sparse_complex_matrix, +)
@@ -182,3 +184,5 @@ install_sm_scm_ops (octave::type_info& ti)
   INSTALL_WIDENOP_TI (ti, octave_sparse_matrix, octave_sparse_complex_matrix,
                       sparse_complex_matrix_conv);
 }
+
+OCTAVE_END_NAMESPACE(octave)
