@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2000-2022 The Octave Project Developers
+// Copyright (C) 2000-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -32,16 +32,17 @@
 #include "comment-list.h"
 #include "error.h"
 
-namespace octave
+OCTAVE_BEGIN_NAMESPACE(octave)
+
+comment_list *
+comment_list::dup (void) const
 {
-  comment_list *
-  comment_list::dup (void) const
-  {
-    comment_list *new_cl = new comment_list ();
+  comment_list *new_cl = new comment_list ();
 
-    for (const auto& elt : *this)
-      new_cl->append (elt);
+  for (const auto& elt : *this)
+    new_cl->append (elt);
 
-    return new_cl;
-  }
+  return new_cl;
 }
+
+OCTAVE_END_NAMESPACE(octave)
