@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2021 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -29,8 +29,7 @@
 #  include "config.h"
 #endif
 
-#include "Array.h"
-#include "Array.cc"
+#include "Array-oct.cc"
 
 #include "ov.h"
 #include "cdef-class.h"
@@ -38,24 +37,22 @@
 
 #include "oct-sort.cc"
 
-// Prevent implicit instantiations on some systems (Windows, others?)
-// that can lead to duplicate definitions of static data members.
+#if defined (HAVE_PRAGMA_GCC_VISIBILITY)
+// Visibility attributes are ignored on template instantiation.
+// As a work-around, set visibility to default overriding compiler options.
+#  pragma GCC visibility push(default)
+#endif
 
-extern template class OCTAVE_API Array<Complex>;
-extern template class OCTAVE_API Array<FloatComplex>;
-extern template class OCTAVE_API Array<bool>;
-extern template class OCTAVE_API Array<char>;
-extern template class OCTAVE_API Array<double>;
-extern template class OCTAVE_API Array<float>;
-extern template class OCTAVE_API Array<idx_vector>;
-extern template class OCTAVE_API Array<octave_idx_type>;
-extern template class OCTAVE_API Array<std::string>;
+NO_INSTANTIATE_ARRAY_SORT_API (octave_value, OCTINTERP_API);
+INSTANTIATE_ARRAY (octave_value, OCTINTERP_CLASS_TEMPLATE_INSTANTIATION_API);
 
-NO_INSTANTIATE_ARRAY_SORT (octave_value);
-INSTANTIATE_ARRAY (octave_value, OCTINTERP_API);
+NO_INSTANTIATE_ARRAY_SORT_API (octave_value *, OCTINTERP_API);
+INSTANTIATE_ARRAY (octave_value *, OCTINTERP_CLASS_TEMPLATE_INSTANTIATION_API);
 
-NO_INSTANTIATE_ARRAY_SORT (octave_value *);
-INSTANTIATE_ARRAY (octave_value *, OCTINTERP_API);
+NO_INSTANTIATE_ARRAY_SORT_API (octave::cdef_object, OCTINTERP_API);
+INSTANTIATE_ARRAY (octave::cdef_object, OCTINTERP_CLASS_TEMPLATE_INSTANTIATION_API);
+
+#if defined (HAVE_PRAGMA_GCC_VISIBILITY)
+#  pragma GCC visibility pop
+#endif
 
-NO_INSTANTIATE_ARRAY_SORT (octave::cdef_object);
-INSTANTIATE_ARRAY (octave::cdef_object, OCTINTERP_API);
