@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1994-2021 The Octave Project Developers
+// Copyright (C) 1994-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -33,14 +33,15 @@
 #include "lo-mappers.h"
 
 #include "Array.h"
-#include "Array.cc"
-#include "oct-sort.cc"
 
 // Prevent implicit instantiations on some systems (Windows, others?)
 // that can lead to duplicate definitions of static data members.
 
-extern template class OCTAVE_API Array<idx_vector>;
-extern template class OCTAVE_API Array<octave_idx_type>;
+extern template class OCTAVE_EXTERN_TEMPLATE_API Array<octave::idx_vector>;
+extern template class Array<octave_idx_type>;
+
+#include "Array-base.cc"
+#include "oct-sort.cc"
 
 template <>
 inline bool
@@ -92,9 +93,9 @@ safe_comparator (sortmode mode, const Array<FloatComplex>& a, bool allow_chk)
   return result;
 }
 
-template class OCTAVE_API octave_sort<FloatComplex>;
+template class octave_sort<FloatComplex>;
 
-INSTANTIATE_ARRAY (FloatComplex, OCTAVE_API);
+INSTANTIATE_ARRAY (FloatComplex, OCTAVE_CLASS_TEMPLATE_INSTANTIATION_API);
 
 template OCTAVE_API std::ostream& operator << (std::ostream&,
                                                const Array<FloatComplex>&);
@@ -102,4 +103,4 @@ template OCTAVE_API std::ostream& operator << (std::ostream&,
 #include "DiagArray2.h"
 #include "DiagArray2.cc"
 
-template class OCTAVE_API DiagArray2<FloatComplex>;
+template class DiagArray2<FloatComplex>;
