@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2021-2022 The Octave Project Developers
+// Copyright (C) 2021-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -28,6 +28,17 @@
 
 #include "octave-config.h"
 
-template <typename T> class OCTAVE_API Sparse;
+#if defined (OCTAVE_HAVE_STD_PMR_POLYMORPHIC_ALLOCATOR)
+#  include <memory_resource>
+
+template <typename T, typename Alloc = std::pmr::polymorphic_allocator<T>>
+class OCTAVE_TEMPLATE_API Sparse;
+
+#else
+
+template <typename T, typename Alloc = std::allocator<T>>
+class OCTAVE_TEMPLATE_API Sparse;
+
+#endif
 
 #endif
