@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1993-2021 The Octave Project Developers
+// Copyright (C) 1993-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -35,20 +35,24 @@
 #include <iosfwd>
 #include <memory>
 
+#include "Array-fwd.h"
 #include "dim-vector.h"
-#include "oct-inttypes-fwd.h"
+#include "oct-inttypes.h"
 #include "oct-refcount.h"
+#include "Sparse-fwd.h"
+#include "range-fwd.h"
 
-template <typename T> class Array;
-template <typename T> class Sparse;
-class Range;
+OCTAVE_BEGIN_NAMESPACE(octave)
 
 // Design rationale:
-// idx_vector is a reference-counting, polymorphic pointer, that can contain
-// 4 types of index objects: a magic colon, a range, a scalar, or an index vector.
-// Polymorphic methods for single element access are provided, as well as
-// templates implementing "early dispatch", i.e., hoisting the checks for index
-// type out of loops.
+//
+// idx_vector is a reference-counting, polymorphic pointer, that can
+// contain 4 types of index objects: a magic colon, a range, a scalar,
+// or an index vector.
+//
+// Polymorphic methods for single element access are provided, as well
+// as templates implementing "early dispatch", i.e., hoisting the checks
+// for index type out of loops.
 
 class
 OCTAVE_API
@@ -74,7 +78,7 @@ private:
   {
   public:
 
-    idx_base_rep (void) : count (1), err (false) { }
+    idx_base_rep (void) : m_count (1) { }
 
     // No copying!
 
@@ -115,9 +119,7 @@ private:
 
     virtual Array<octave_idx_type> as_array (void);
 
-    octave::refcount<octave_idx_type> count;
-
-    bool err;
+    refcount<octave_idx_type> m_count;
   };
 
   // The magic colon index.
@@ -127,7 +129,7 @@ private:
 
     idx_colon_rep (void) = default;
 
-    idx_colon_rep (char c);
+    OCTAVE_API idx_colon_rep (char c);
 
     // No copying!
 
@@ -137,7 +139,7 @@ private:
 
     octave_idx_type xelem (octave_idx_type i) const { return i; }
 
-    octave_idx_type checkelem (octave_idx_type i) const;
+    OCTAVE_API octave_idx_type checkelem (octave_idx_type i) const;
 
     octave_idx_type length (octave_idx_type n) const { return n; }
 
@@ -146,13 +148,13 @@ private:
     idx_class_type idx_class (void) const { return class_colon; }
 
     idx_base_rep * sort_uniq_clone (bool = false)
-    { count++; return this; }
+    { m_count++; return this; }
 
     OCTAVE_NORETURN idx_base_rep * sort_idx (Array<octave_idx_type>&);
 
     bool is_colon_equiv (octave_idx_type) const { return true; }
 
-    std::ostream& print (std::ostream& os) const;
+    OCTAVE_API std::ostream& print (std::ostream& os) const;
   };
 
   // To distinguish the "direct" constructors that blindly trust the data.
@@ -165,15 +167,16 @@ private:
 
     idx_range_rep (void) = delete;
 
-    idx_range_rep (octave_idx_type _start, octave_idx_type _len,
-                   octave_idx_type _step, direct)
-      : idx_base_rep (), start(_start), len(_len), step(_step) { }
+    idx_range_rep (octave_idx_type start, octave_idx_type len,
+                   octave_idx_type step, direct)
+      : idx_base_rep (), m_start (start), m_len (len), m_step (step) { }
 
-    // Zero-based constructor.
-    idx_range_rep (octave_idx_type _start, octave_idx_type _limit,
-                   octave_idx_type _step);
+    // Zero-based constructor for index range starting at `start` (inclusive)
+    // and ending at `limit` (exclusive) in steps of `step`.
+    idx_range_rep (octave_idx_type start, octave_idx_type limit,
+                   octave_idx_type step);
 
-    idx_range_rep (const Range&);
+    OCTAVE_API idx_range_rep (const range<double>&);
 
     // No copying!
 
@@ -182,43 +185,42 @@ private:
     idx_range_rep& operator = (const idx_range_rep& idx) = delete;
 
     octave_idx_type xelem (octave_idx_type i) const
-    { return start + i * step; }
+    { return m_start + i * m_step; }
 
     octave_idx_type checkelem (octave_idx_type i) const;
 
-    octave_idx_type length (octave_idx_type) const { return len; }
+    octave_idx_type length (octave_idx_type) const { return m_len; }
 
     octave_idx_type extent (octave_idx_type n) const
     {
-      return len ? std::max (n, start + 1 + (step < 0 ? 0 : step * (len - 1)))
-                 : n;
+      return m_len ? std::max (n, m_start + 1 + (m_step < 0 ? 0 : m_step * (m_len - 1))) : n;
     }
 
     idx_class_type idx_class (void) const { return class_range; }
 
-    idx_base_rep * sort_uniq_clone (bool uniq = false);
+    OCTAVE_API idx_base_rep * sort_uniq_clone (bool uniq = false);
 
-    idx_base_rep * sort_idx (Array<octave_idx_type>&);
+    OCTAVE_API idx_base_rep * sort_idx (Array<octave_idx_type>&);
 
     bool is_colon_equiv (octave_idx_type n) const
-    { return start == 0 && step == 1 && len == n; }
+    { return m_start == 0 && m_step == 1 && m_len == n; }
 
     dim_vector orig_dimensions (void) const
-    { return dim_vector (1, len); }
+    { return dim_vector (1, m_len); }
 
-    octave_idx_type get_start (void) const { return start; }
+    octave_idx_type get_start (void) const { return m_start; }
 
-    octave_idx_type get_step (void) const { return step; }
+    octave_idx_type get_step (void) const { return m_step; }
 
-    std::ostream& print (std::ostream& os) const;
+    OCTAVE_API std::ostream& print (std::ostream& os) const;
 
-    Range unconvert (void) const;
+    OCTAVE_API range<double> unconvert (void) const;
 
-    Array<octave_idx_type> as_array (void);
+    OCTAVE_API Array<octave_idx_type> as_array (void);
 
   private:
 
-    octave_idx_type start, len, step;
+    octave_idx_type m_start, m_len, m_step;
   };
 
   // The integer scalar index.
@@ -228,8 +230,7 @@ private:
 
     idx_scalar_rep (void) = delete;
 
-    idx_scalar_rep (octave_idx_type i, direct)
-      : idx_base_rep (), data (i) { }
+    idx_scalar_rep (octave_idx_type i, direct) : idx_base_rep (), m_data (i) { }
 
     // No copying!
 
@@ -238,43 +239,43 @@ private:
     idx_scalar_rep& operator = (const idx_scalar_rep& idx) = delete;
 
     // Zero-based constructor.
-    idx_scalar_rep (octave_idx_type i);
+    OCTAVE_API idx_scalar_rep (octave_idx_type i);
 
     template <typename T>
     idx_scalar_rep (T x);
 
-    octave_idx_type xelem (octave_idx_type) const { return data; }
+    octave_idx_type xelem (octave_idx_type) const { return m_data; }
 
-    octave_idx_type checkelem (octave_idx_type i) const;
+    OCTAVE_API octave_idx_type checkelem (octave_idx_type i) const;
 
     octave_idx_type length (octave_idx_type) const { return 1; }
 
     octave_idx_type extent (octave_idx_type n) const
-    { return std::max (n, data + 1); }
+    { return std::max (n, m_data + 1); }
 
     idx_class_type idx_class (void) const { return class_scalar; }
 
     idx_base_rep * sort_uniq_clone (bool = false)
-    { count++; return this; }
+    { m_count++; return this; }
 
-    idx_base_rep * sort_idx (Array<octave_idx_type>&);
+    OCTAVE_API idx_base_rep * sort_idx (Array<octave_idx_type>&);
 
     bool is_colon_equiv (octave_idx_type n) const
-    { return n == 1 && data == 0; }
+    { return n == 1 && m_data == 0; }
 
     dim_vector orig_dimensions (void) const { return dim_vector (1, 1); }
 
-    octave_idx_type get_data (void) const { return data; }
+    octave_idx_type get_data (void) const { return m_data; }
 
-    std::ostream& print (std::ostream& os) const;
+    OCTAVE_API std::ostream& print (std::ostream& os) const;
 
-    double unconvert (void) const;
+    OCTAVE_API double unconvert (void) const;
 
-    Array<octave_idx_type> as_array (void);
+    OCTAVE_API Array<octave_idx_type> as_array (void);
 
   private:
 
-    octave_idx_type data;
+    octave_idx_type m_data;
   };
 
   // The integer vector index.
@@ -283,30 +284,29 @@ private:
   public:
 
     idx_vector_rep (void)
-      : data (nullptr), len (0), ext (0), aowner (nullptr), orig_dims ()
-    { }
+      : m_data (nullptr), m_len (0), m_ext (0), m_aowner (nullptr), m_orig_dims () { }
 
     // Direct constructor.
-    idx_vector_rep (octave_idx_type *_data, octave_idx_type _len,
-                    octave_idx_type _ext, const dim_vector& od, direct)
-      : idx_base_rep (), data (_data), len (_len), ext (_ext),
-        aowner (nullptr), orig_dims (od)
+    idx_vector_rep (octave_idx_type *data, octave_idx_type len,
+                    octave_idx_type ext, const dim_vector& od, direct)
+      : idx_base_rep (), m_data (data), m_len (len), m_ext (ext),
+        m_aowner (nullptr), m_orig_dims (od)
     { }
 
     // Zero-based constructor.
-    idx_vector_rep (const Array<octave_idx_type>& inda);
+    OCTAVE_API idx_vector_rep (const Array<octave_idx_type>& inda);
 
-    idx_vector_rep (const Array<octave_idx_type>& inda,
-                    octave_idx_type _ext, direct);
+    OCTAVE_API idx_vector_rep (const Array<octave_idx_type>& inda,
+                               octave_idx_type ext, direct);
 
     template <typename T>
     idx_vector_rep (const Array<T>&);
 
-    idx_vector_rep (bool);
+    OCTAVE_API idx_vector_rep (bool);
 
-    idx_vector_rep (const Array<bool>&, octave_idx_type = -1);
+    OCTAVE_API idx_vector_rep (const Array<bool>&, octave_idx_type = -1);
 
-    idx_vector_rep (const Sparse<bool>&);
+    OCTAVE_API idx_vector_rep (const Sparse<bool>&);
 
     // No copying!
 
@@ -316,36 +316,36 @@ private:
 
     ~idx_vector_rep (void);
 
-    octave_idx_type xelem (octave_idx_type i) const { return data[i]; }
+    octave_idx_type xelem (octave_idx_type i) const { return m_data[i]; }
 
-    octave_idx_type checkelem (octave_idx_type i) const;
+    OCTAVE_API octave_idx_type checkelem (octave_idx_type i) const;
 
-    octave_idx_type length (octave_idx_type) const { return len; }
+    octave_idx_type length (octave_idx_type) const { return m_len; }
 
     octave_idx_type extent (octave_idx_type n) const
-    { return std::max (n, ext); }
+    { return std::max (n, m_ext); }
 
     idx_class_type idx_class (void) const { return class_vector; }
 
     idx_base_rep * sort_uniq_clone (bool uniq = false);
 
-    idx_base_rep * sort_idx (Array<octave_idx_type>&);
+    OCTAVE_API idx_base_rep * sort_idx (Array<octave_idx_type>&);
 
-    dim_vector orig_dimensions (void) const { return orig_dims; }
+    dim_vector orig_dimensions (void) const { return m_orig_dims; }
 
-    const octave_idx_type * get_data (void) const { return data; }
+    const octave_idx_type * get_data (void) const { return m_data; }
 
-    std::ostream& print (std::ostream& os) const;
+    OCTAVE_API std::ostream& print (std::ostream& os) const;
 
-    Array<double> unconvert (void) const;
+    OCTAVE_API Array<double> unconvert (void) const;
 
-    Array<octave_idx_type> as_array (void);
+    OCTAVE_API Array<octave_idx_type> as_array (void);
 
   private:
 
-    const octave_idx_type *data;
-    octave_idx_type len;
-    octave_idx_type ext;
+    const octave_idx_type *m_data;
+    octave_idx_type m_len;
+    octave_idx_type m_ext;
 
     // This is a trick to allow user-given zero-based arrays to be used
     // as indices without copying.  If the following pointer is nonzero,
@@ -354,9 +354,9 @@ private:
     // because we deferred the Array<T> declaration and we do not want
     // it yet to be defined.
 
-    Array<octave_idx_type> *aowner;
+    Array<octave_idx_type> *m_aowner;
 
-    dim_vector orig_dims;
+    dim_vector m_orig_dims;
   };
 
   // The logical mask index.
@@ -367,15 +367,15 @@ private:
     idx_mask_rep (void) = delete;
 
     // Direct constructor.
-    idx_mask_rep (bool *_data, octave_idx_type _len,
-                  octave_idx_type _ext, const dim_vector& od, direct)
-      : idx_base_rep (), data (_data), len (_len), ext (_ext),
-        lsti (-1), lste (-1), aowner (nullptr), orig_dims (od)
+    idx_mask_rep (bool *data, octave_idx_type len,
+                  octave_idx_type ext, const dim_vector& od, direct)
+      : idx_base_rep (), m_data (data), m_len (len), m_ext (ext),
+        m_lsti (-1), m_lste (-1), m_aowner (nullptr), m_orig_dims (od)
     { }
 
-    idx_mask_rep (bool);
+    OCTAVE_API idx_mask_rep (bool);
 
-    idx_mask_rep (const Array<bool>&, octave_idx_type = -1);
+    OCTAVE_API idx_mask_rep (const Array<bool>&, octave_idx_type = -1);
 
     // No copying!
 
@@ -383,47 +383,47 @@ private:
 
     idx_mask_rep& operator = (const idx_mask_rep& idx) = delete;
 
-    ~idx_mask_rep (void);
+    OCTAVE_API ~idx_mask_rep (void);
 
     octave_idx_type xelem (octave_idx_type i) const;
 
     octave_idx_type checkelem (octave_idx_type i) const;
 
-    octave_idx_type length (octave_idx_type) const { return len; }
+    octave_idx_type length (octave_idx_type) const { return m_len; }
 
     octave_idx_type extent (octave_idx_type n) const
-    { return std::max (n, ext); }
+    { return std::max (n, m_ext); }
 
     idx_class_type idx_class (void) const { return class_mask; }
 
     idx_base_rep * sort_uniq_clone (bool = false)
-    { count++; return this; }
+    { m_count++; return this; }
 
-    idx_base_rep * sort_idx (Array<octave_idx_type>&);
+    OCTAVE_API idx_base_rep * sort_idx (Array<octave_idx_type>&);
 
-    dim_vector orig_dimensions (void) const { return orig_dims; }
+    dim_vector orig_dimensions (void) const { return m_orig_dims; }
 
     bool is_colon_equiv (octave_idx_type n) const
-    { return len == n && ext == n; }
+    { return m_len == n && m_ext == n; }
 
-    const bool * get_data (void) const { return data; }
+    const bool * get_data (void) const { return m_data; }
 
-    std::ostream& print (std::ostream& os) const;
+    OCTAVE_API std::ostream& print (std::ostream& os) const;
 
-    Array<bool> unconvert (void) const;
+    OCTAVE_API Array<bool> unconvert (void) const;
 
-    Array<octave_idx_type> as_array (void);
+    OCTAVE_API Array<octave_idx_type> as_array (void);
 
   private:
 
-    const bool *data;
-    octave_idx_type len;
-    octave_idx_type ext;
+    const bool *m_data;
+    octave_idx_type m_len;
+    octave_idx_type m_ext;
 
     // FIXME: I'm not sure if this is a good design.  Maybe it would be
     // better to employ some sort of generalized iteration scheme.
-    mutable octave_idx_type lsti;
-    mutable octave_idx_type lste;
+    mutable octave_idx_type m_lsti;
+    mutable octave_idx_type m_lste;
 
     // This is a trick to allow user-given mask arrays to be used as
     // indices without copying.  If the following pointer is nonzero, we
@@ -432,52 +432,39 @@ private:
     // deferred the Array<T> declaration and we do not want it yet to be
     // defined.
 
-    Array<bool> *aowner;
+    Array<bool> *m_aowner;
 
-    dim_vector orig_dims;
+    dim_vector m_orig_dims;
   };
 
-  idx_vector (idx_base_rep *r) : rep (r) { }
+  idx_vector (idx_base_rep *r) : m_rep (r) { }
 
   // The shared empty vector representation (for fast default
   // constructor).
-  static idx_vector_rep *nil_rep (void);
-
-  // The shared empty vector representation with the error flag set.
-  static idx_vector_rep *err_rep (void);
-
-  // If there was an error in constructing the rep, replace it with
-  // empty vector for safety.
-  void chkerr (void)
-  {
-    if (rep->err)
-      {
-        if (--rep->count == 0)
-          delete rep;
-        rep = err_rep ();
-        rep->count++;
-      }
-  }
+  static OCTAVE_API idx_vector_rep * nil_rep (void);
 
 public:
 
   // Fast empty constructor.
-  idx_vector (void) : rep (nil_rep ()) { rep->count++; }
+  idx_vector (void) : m_rep (nil_rep ()) { m_rep->m_count++; }
 
   // Zero-based constructors (for use from C++).
-  idx_vector (octave_idx_type i) : rep (new idx_scalar_rep (i))
-  { chkerr (); }
+  idx_vector (octave_idx_type i) : m_rep (new idx_scalar_rep (i)) { }
 
-#if OCTAVE_SIZEOF_F77_INT_TYPE != OCTAVE_SIZEOF_IDX_TYPE
+#if OCTAVE_SIZEOF_INT != OCTAVE_SIZEOF_IDX_TYPE
+  idx_vector (int i)
+    : m_rep (new idx_scalar_rep (static_cast<octave_idx_type> (i))) { }
+#endif
+
+#if (OCTAVE_SIZEOF_F77_INT_TYPE != OCTAVE_SIZEOF_IDX_TYPE \
+     && OCTAVE_SIZEOF_F77_INT_TYPE != OCTAVE_SIZEOF_INT)
   idx_vector (octave_f77_int_type i)
-    : rep (new idx_scalar_rep (static_cast<octave_idx_type> (i)))
-  { chkerr (); }
+    : m_rep (new idx_scalar_rep (static_cast<octave_idx_type> (i))) { }
 #endif
 
   idx_vector (octave_idx_type start, octave_idx_type limit,
               octave_idx_type step = 1)
-    : rep (new idx_range_rep (start, limit, step))
-  { chkerr (); }
+    : m_rep (new idx_range_rep (start, limit, step)) { }
 
   static idx_vector
   make_range (octave_idx_type start, octave_idx_type step,
@@ -487,111 +474,105 @@ public:
   }
 
   idx_vector (const Array<octave_idx_type>& inda)
-    : rep (new idx_vector_rep (inda))
-  { chkerr (); }
+    : m_rep (new idx_vector_rep (inda)) { }
 
   // Directly pass extent, no checking.
   idx_vector (const Array<octave_idx_type>& inda, octave_idx_type ext)
-    : rep (new idx_vector_rep (inda, ext, DIRECT))
-  { }
+    : m_rep (new idx_vector_rep (inda, ext, DIRECT)) { }
 
   // Colon is best constructed by simply copying (or referencing) this member.
   static const idx_vector colon;
 
   // or passing ':' here
-  idx_vector (char c) : rep (new idx_colon_rep (c)) { chkerr (); }
+  idx_vector (char c) : m_rep (new idx_colon_rep (c)) { }
 
   // Conversion constructors (used by interpreter).
 
   template <typename T>
-  idx_vector (octave_int<T> x) : rep (new idx_scalar_rep (x)) { chkerr (); }
+  idx_vector (octave_int<T> x) : m_rep (new idx_scalar_rep (x)) { }
 
-  idx_vector (double x) : rep (new idx_scalar_rep (x)) { chkerr (); }
+  idx_vector (double x) : m_rep (new idx_scalar_rep (x)) { }
 
-  idx_vector (float x) : rep (new idx_scalar_rep (x)) { chkerr (); }
+  idx_vector (float x) : m_rep (new idx_scalar_rep (x)) { }
 
   // A scalar bool does not necessarily map to scalar index.
-  idx_vector (bool x) : rep (new idx_mask_rep (x)) { chkerr (); }
+  idx_vector (bool x) : m_rep (new idx_mask_rep (x)) { }
 
   template <typename T>
-  idx_vector (const Array<octave_int<T>>& nda) : rep (new idx_vector_rep (nda))
-  { chkerr (); }
+  idx_vector (const Array<octave_int<T>>& nda)
+    : m_rep (new idx_vector_rep (nda)) { }
 
-  idx_vector (const Array<double>& nda) : rep (new idx_vector_rep (nda))
-  { chkerr (); }
+  idx_vector (const Array<double>& nda) : m_rep (new idx_vector_rep (nda)) { }
 
-  idx_vector (const Array<float>& nda) : rep (new idx_vector_rep (nda))
-  { chkerr (); }
+  idx_vector (const Array<float>& nda) : m_rep (new idx_vector_rep (nda)) { }
 
-  idx_vector (const Array<bool>& nda);
+  OCTAVE_API idx_vector (const Array<bool>& nda);
 
-  idx_vector (const Range& r)
-    : rep (new idx_range_rep (r))
-  { chkerr (); }
+  idx_vector (const range<double>& r) : m_rep (new idx_range_rep (r)) { }
 
-  idx_vector (const Sparse<bool>& nda) : rep (new idx_vector_rep (nda))
-  { chkerr (); }
+  idx_vector (const Sparse<bool>& nda) : m_rep (new idx_vector_rep (nda)) { }
 
-  idx_vector (const idx_vector& a) : rep (a.rep) { rep->count++; }
+  idx_vector (const idx_vector& a) : m_rep (a.m_rep) { m_rep->m_count++; }
 
   ~idx_vector (void)
   {
-    if (--rep->count == 0 && rep != nil_rep ())
-      delete rep;
+    if (--m_rep->m_count == 0 && m_rep != nil_rep ())
+      delete m_rep;
   }
 
   idx_vector& operator = (const idx_vector& a)
   {
     if (this != &a)
       {
-        if (--rep->count == 0 && rep != nil_rep ())
-          delete rep;
+        if (--m_rep->m_count == 0 && m_rep != nil_rep ())
+          delete m_rep;
 
-        rep = a.rep;
-        rep->count++;
+        m_rep = a.m_rep;
+        m_rep->m_count++;
       }
     return *this;
   }
 
-  idx_class_type idx_class (void) const { return rep->idx_class (); }
+  idx_class_type idx_class (void) const { return m_rep->idx_class (); }
 
   octave_idx_type length (octave_idx_type n = 0) const
-  { return rep->length (n); }
+  { return m_rep->length (n); }
 
   octave_idx_type extent (octave_idx_type n) const
-  { return rep->extent (n); }
+  { return m_rep->extent (n); }
 
   octave_idx_type xelem (octave_idx_type n) const
-  { return rep->xelem (n); }
+  { return m_rep->xelem (n); }
 
   octave_idx_type checkelem (octave_idx_type n) const
-  { return rep->xelem (n); }
+  { return m_rep->xelem (n); }
 
   octave_idx_type operator () (octave_idx_type n) const
-  { return rep->xelem (n); }
+  { return m_rep->xelem (n); }
 
-  operator bool (void) const
-  { return ! rep->err; }
+  // FIXME: idx_vector objects are either created successfully or an
+  // error is thrown, so this method no longer makes sense.
+  operator bool (void) const { return true; }
 
   bool is_colon (void) const
-  { return rep->idx_class () == class_colon; }
+  { return m_rep->idx_class () == class_colon; }
 
   bool is_scalar (void) const
-  { return rep->idx_class () == class_scalar; }
+  { return m_rep->idx_class () == class_scalar; }
 
   bool is_range (void) const
-  { return rep->idx_class () == class_range; }
+  { return m_rep->idx_class () == class_range; }
 
   bool is_colon_equiv (octave_idx_type n) const
-  { return rep->is_colon_equiv (n); }
+  { return m_rep->is_colon_equiv (n); }
 
   idx_vector sorted (bool uniq = false) const
-  { return idx_vector (rep->sort_uniq_clone (uniq)); }
+  { return idx_vector (m_rep->sort_uniq_clone (uniq)); }
 
   idx_vector sorted (Array<octave_idx_type>& sidx) const
-  { return idx_vector (rep->sort_idx (sidx)); }
+  { return idx_vector (m_rep->sort_idx (sidx)); }
 
-  dim_vector orig_dimensions (void) const { return rep->orig_dimensions (); }
+  dim_vector orig_dimensions (void) const { return m_rep->orig_dimensions (); }
 
   octave_idx_type orig_rows (void) const
   { return orig_dimensions () (0); }
@@ -604,7 +585,7 @@ public:
 
   // i/o
 
-  std::ostream& print (std::ostream& os) const { return rep->print (os); }
+  std::ostream& print (std::ostream& os) const { return m_rep->print (os); }
 
   friend std::ostream& operator << (std::ostream& os, const idx_vector& a)
   { return a.print (os); }
@@ -621,9 +602,9 @@ public:
   octave_idx_type
   index (const T *src, octave_idx_type n, T *dest) const
   {
-    octave_idx_type len = rep->length (n);
+    octave_idx_type len = m_rep->length (n);
 
-    switch (rep->idx_class ())
+    switch (m_rep->idx_class ())
       {
       case class_colon:
         std::copy_n (src, len, dest);
@@ -631,7 +612,7 @@ public:
 
       case class_range:
         {
-          idx_range_rep *r = dynamic_cast<idx_range_rep *> (rep);
+          idx_range_rep *r = dynamic_cast<idx_range_rep *> (m_rep);
           octave_idx_type start = r->get_start ();
           octave_idx_type step = r->get_step ();
           const T *ssrc = src + start;
@@ -651,14 +632,14 @@ public:
 
       case class_scalar:
         {
-          idx_scalar_rep *r = dynamic_cast<idx_scalar_rep *> (rep);
+          idx_scalar_rep *r = dynamic_cast<idx_scalar_rep *> (m_rep);
           dest[0] = src[r->get_data ()];
         }
         break;
 
       case class_vector:
         {
-          idx_vector_rep *r = dynamic_cast<idx_vector_rep *> (rep);
+          idx_vector_rep *r = dynamic_cast<idx_vector_rep *> (m_rep);
           const octave_idx_type *data = r->get_data ();
           for (octave_idx_type i = 0; i < len; i++)
             dest[i] = src[data[i]];
@@ -667,7 +648,7 @@ public:
 
       case class_mask:
         {
-          idx_mask_rep *r = dynamic_cast<idx_mask_rep *> (rep);
+          idx_mask_rep *r = dynamic_cast<idx_mask_rep *> (m_rep);
           const bool *data = r->get_data ();
           octave_idx_type ext = r->extent (0);
           for (octave_idx_type i = 0; i < ext; i++)
@@ -695,9 +676,9 @@ public:
   octave_idx_type
   assign (const T *src, octave_idx_type n, T *dest) const
   {
-    octave_idx_type len = rep->length (n);
+    octave_idx_type len = m_rep->length (n);
 
-    switch (rep->idx_class ())
+    switch (m_rep->idx_class ())
       {
       case class_colon:
         std::copy_n (src, len, dest);
@@ -705,7 +686,7 @@ public:
 
       case class_range:
         {
-          idx_range_rep *r = dynamic_cast<idx_range_rep *> (rep);
+          idx_range_rep *r = dynamic_cast<idx_range_rep *> (m_rep);
           octave_idx_type start = r->get_start ();
           octave_idx_type step = r->get_step ();
           T *sdest = dest + start;
@@ -723,14 +704,14 @@ public:
 
       case class_scalar:
         {
-          idx_scalar_rep *r = dynamic_cast<idx_scalar_rep *> (rep);
+          idx_scalar_rep *r = dynamic_cast<idx_scalar_rep *> (m_rep);
           dest[r->get_data ()] = src[0];
         }
         break;
 
       case class_vector:
         {
-          idx_vector_rep *r = dynamic_cast<idx_vector_rep *> (rep);
+          idx_vector_rep *r = dynamic_cast<idx_vector_rep *> (m_rep);
           const octave_idx_type *data = r->get_data ();
           for (octave_idx_type i = 0; i < len; i++)
             dest[data[i]] = src[i];
@@ -739,7 +720,7 @@ public:
 
       case class_mask:
         {
-          idx_mask_rep *r = dynamic_cast<idx_mask_rep *> (rep);
+          idx_mask_rep *r = dynamic_cast<idx_mask_rep *> (m_rep);
           const bool *data = r->get_data ();
           octave_idx_type ext = r->extent (0);
           for (octave_idx_type i = 0; i < ext; i++)
@@ -767,9 +748,9 @@ public:
   octave_idx_type
   fill (const T& val, octave_idx_type n, T *dest) const
   {
-    octave_idx_type len = rep->length (n);
+    octave_idx_type len = m_rep->length (n);
 
-    switch (rep->idx_class ())
+    switch (m_rep->idx_class ())
       {
       case class_colon:
         std::fill_n (dest, len, val);
@@ -777,7 +758,7 @@ public:
 
       case class_range:
         {
-          idx_range_rep *r = dynamic_cast<idx_range_rep *> (rep);
+          idx_range_rep *r = dynamic_cast<idx_range_rep *> (m_rep);
           octave_idx_type start = r->get_start ();
           octave_idx_type step = r->get_step ();
           T *sdest = dest + start;
@@ -795,14 +776,14 @@ public:
 
       case class_scalar:
         {
-          idx_scalar_rep *r = dynamic_cast<idx_scalar_rep *> (rep);
+          idx_scalar_rep *r = dynamic_cast<idx_scalar_rep *> (m_rep);
           dest[r->get_data ()] = val;
         }
         break;
 
       case class_vector:
         {
-          idx_vector_rep *r = dynamic_cast<idx_vector_rep *> (rep);
+          idx_vector_rep *r = dynamic_cast<idx_vector_rep *> (m_rep);
           const octave_idx_type *data = r->get_data ();
           for (octave_idx_type i = 0; i < len; i++)
             dest[data[i]] = val;
@@ -811,7 +792,7 @@ public:
 
       case class_mask:
         {
-          idx_mask_rep *r = dynamic_cast<idx_mask_rep *> (rep);
+          idx_mask_rep *r = dynamic_cast<idx_mask_rep *> (m_rep);
           const bool *data = r->get_data ();
           octave_idx_type ext = r->extent (0);
           for (octave_idx_type i = 0; i < ext; i++)
@@ -837,9 +818,9 @@ public:
   void
   loop (octave_idx_type n, Functor body) const
   {
-    octave_idx_type len = rep->length (n);
+    octave_idx_type len = m_rep->length (n);
 
-    switch (rep->idx_class ())
+    switch (m_rep->idx_class ())
       {
       case class_colon:
         for (octave_idx_type i = 0; i < len; i++) body (i);
@@ -847,7 +828,7 @@ public:
 
       case class_range:
         {
-          idx_range_rep *r = dynamic_cast<idx_range_rep *> (rep);
+          idx_range_rep *r = dynamic_cast<idx_range_rep *> (m_rep);
           octave_idx_type start = r->get_start ();
           octave_idx_type step = r->get_step ();
           octave_idx_type i, j;
@@ -862,14 +843,14 @@ public:
 
       case class_scalar:
         {
-          idx_scalar_rep *r = dynamic_cast<idx_scalar_rep *> (rep);
+          idx_scalar_rep *r = dynamic_cast<idx_scalar_rep *> (m_rep);
           body (r->get_data ());
         }
         break;
 
       case class_vector:
         {
-          idx_vector_rep *r = dynamic_cast<idx_vector_rep *> (rep);
+          idx_vector_rep *r = dynamic_cast<idx_vector_rep *> (m_rep);
           const octave_idx_type *data = r->get_data ();
           for (octave_idx_type i = 0; i < len; i++) body (data[i]);
         }
@@ -877,7 +858,7 @@ public:
 
       case class_mask:
         {
-          idx_mask_rep *r = dynamic_cast<idx_mask_rep *> (rep);
+          idx_mask_rep *r = dynamic_cast<idx_mask_rep *> (m_rep);
           const bool *data = r->get_data ();
           octave_idx_type ext = r->extent (0);
           for (octave_idx_type i = 0; i < ext; i++)
@@ -905,9 +886,9 @@ public:
   octave_idx_type
   bloop (octave_idx_type n, Functor body) const
   {
-    octave_idx_type len = rep->length (n), ret;
+    octave_idx_type len = m_rep->length (n), ret;
 
-    switch (rep->idx_class ())
+    switch (m_rep->idx_class ())
       {
       case class_colon:
         {
@@ -919,7 +900,7 @@ public:
 
       case class_range:
         {
-          idx_range_rep *r = dynamic_cast<idx_range_rep *> (rep);
+          idx_range_rep *r = dynamic_cast<idx_range_rep *> (m_rep);
           octave_idx_type start = r->get_start ();
           octave_idx_type step = r->get_step ();
           octave_idx_type i, j;
@@ -935,14 +916,14 @@ public:
 
       case class_scalar:
         {
-          idx_scalar_rep *r = dynamic_cast<idx_scalar_rep *> (rep);
+          idx_scalar_rep *r = dynamic_cast<idx_scalar_rep *> (m_rep);
           ret = (body (r->get_data ()) ? 1 : 0);
         }
         break;
 
       case class_vector:
         {
-          idx_vector_rep *r = dynamic_cast<idx_vector_rep *> (rep);
+          idx_vector_rep *r = dynamic_cast<idx_vector_rep *> (m_rep);
           const octave_idx_type *data = r->get_data ();
           octave_idx_type i;
           for (i = 0; i < len && body (data[i]); i++) ;
@@ -952,7 +933,7 @@ public:
 
       case class_mask:
         {
-          idx_mask_rep *r = dynamic_cast<idx_mask_rep *> (rep);
+          idx_mask_rep *r = dynamic_cast<idx_mask_rep *> (m_rep);
           const bool *data = r->get_data ();
           octave_idx_type ext = r->extent (0);
           octave_idx_type j = 0;
@@ -986,43 +967,44 @@ public:
   // A(i,j)(:) is equal to A(k)(:).
 
   // If the next index can be reduced, returns true and updates this.
-  bool maybe_reduce (octave_idx_type n, const idx_vector& j,
-                     octave_idx_type nj);
+  OCTAVE_API bool
+  maybe_reduce (octave_idx_type n, const idx_vector& j, octave_idx_type nj);
 
-  bool is_cont_range (octave_idx_type n,
-                      octave_idx_type& l, octave_idx_type& u) const;
+  OCTAVE_API bool
+  is_cont_range (octave_idx_type n, octave_idx_type& l,
+                 octave_idx_type& u) const;
 
   // Returns the increment for ranges and colon, 0 for scalars and empty
   // vectors, 1st difference otherwise.
-  octave_idx_type increment (void) const;
+  OCTAVE_API octave_idx_type increment (void) const;
 
-  idx_vector
+  OCTAVE_API idx_vector
   complement (octave_idx_type n) const;
 
-  bool is_permutation (octave_idx_type n) const;
+  OCTAVE_API bool is_permutation (octave_idx_type n) const;
 
   // Returns the inverse permutation.  If this is not a permutation on 1:n, the
   // result is undefined (but no error unless extent () != n).
-  idx_vector inverse_permutation (octave_idx_type n) const;
+  OCTAVE_API idx_vector inverse_permutation (octave_idx_type n) const;
 
   // Copies all the indices to a given array.  Not allowed for colons.
-  void copy_data (octave_idx_type *data) const;
+  OCTAVE_API void copy_data (octave_idx_type *data) const;
 
   // If the index is a mask, convert it to index vector.
-  idx_vector unmask (void) const;
+  OCTAVE_API idx_vector unmask (void) const;
 
   // Unconverts the index to a scalar, Range, double array or a mask.
-  void unconvert (idx_class_type& iclass,
-                  double& scalar, Range& range,
-                  Array<double>& array, Array<bool>& mask) const;
+  OCTAVE_API void
+  unconvert (idx_class_type& iclass, double& scalar, range<double>& range,
+             Array<double>& array, Array<bool>& mask) const;
 
-  Array<octave_idx_type> as_array (void) const;
+  OCTAVE_API Array<octave_idx_type> as_array (void) const;
 
   // Raw pointer to index array.  This is non-const because it may be
   // necessary to mutate the index.
-  const octave_idx_type * raw (void);
+  const OCTAVE_API octave_idx_type * raw (void);
 
-  bool isvector (void) const;
+  OCTAVE_API bool isvector (void) const;
 
   // FIXME: these are here for compatibility.  They should be removed
   // when no longer in use.
@@ -1033,20 +1015,27 @@ public:
   bool is_colon_equiv (octave_idx_type n, int) const
   { return is_colon_equiv (n); }
 
-  octave_idx_type
+  OCTAVE_API octave_idx_type
   freeze (octave_idx_type z_len, const char *tag, bool resize_ok = false);
 
   void sort (bool uniq = false)
   { *this = sorted (uniq); }
 
-  octave_idx_type ones_count (void) const;
+  OCTAVE_API octave_idx_type ones_count (void) const;
 
   octave_idx_type max (void) const { return extent (1) - 1; }
 
 private:
 
-  idx_base_rep *rep;
+  idx_base_rep *m_rep;
 
 };
 
+OCTAVE_END_NAMESPACE(octave)
+
+// Provide the following typedef for backward compatibility.  Don't
+// deprecate (yet) because it is used extensively.
+
+typedef octave::idx_vector idx_vector;
+
 #endif
