@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2016-2021 The Octave Project Developers
+// Copyright (C) 2016-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -36,7 +36,7 @@
 extern "C" {
 #endif
 
-extern int
+extern OCTAVE_API int
 octave_nanosleep_wrapper (const struct timespec *requested,
                           struct timespec *remaining);
 
