@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2016-2020 The Octave Project Developers
+## Copyright (C) 2016-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -30,7 +30,7 @@
 ## Play audio data @var{y} at sample rate @var{fs} to the default audio
 ## device.
 ##
-## The audio signal @var{y} can be a vector or a two-column array, representing
+## The audio signal @var{y} can be a vector or a two-column array representing
 ## mono or stereo audio, respectively.
 ##
 ## If @var{fs} is not given, a default sample rate of 8000 samples per second
@@ -40,18 +40,18 @@
 ## audio device and defaults to 8 bits.
 ##
 ## For more control over audio playback, use the @code{audioplayer} class.
-## @seealso{soundsc, record}
+## @seealso{soundsc, @audioplayer/audioplayer, record}
 ## @end deftypefn
 
 function sound (y, fs, nbits)
 
-  if (nargin < 1 || nargin > 3)
+  if (nargin < 1)
     print_usage ();
   endif
 
   if (nargin < 2 || isempty (fs))
     fs = 8000;
-  elseif (! (isscalar (fs) && (fs > 0)))
+  elseif (! (isscalar (fs) && fs > 0))
     error ("sound: sample rate FS must be a positive number");
   endif
 
@@ -71,7 +71,7 @@ endfunction
 ## Tests of sound must not actually play anything.
 
 ## Test input validation
-%!error sound ()
-%!error sound (1,2,3,4)
-%!error sound (1, -1)
-%!error sound (1, [], 2)
+%!error <Invalid call> sound ()
+%!error <FS must be a positive number> sound (1, ones (2,2))
+%!error <FS must be a positive number> sound (1, -1)
+%!error <NBITS must be 8, 16, or 24> sound (1, [], 2)
