@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2016-2021 The Octave Project Developers
+## Copyright (C) 2016-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -31,7 +31,7 @@
 ## Scale the audio data @var{y} and play it at sample rate @var{fs} to the
 ## default audio device.
 ##
-## The audio signal @var{y} can be a vector or a two-column array, representing
+## The audio signal @var{y} can be a vector or a two-column array representing
 ## mono or stereo audio, respectively.
 ##
 ## If @var{fs} is not given, a default sample rate of 8000 samples per second
@@ -46,25 +46,21 @@
 ## are scaled to the range [-1, 1] instead.
 ##
 ## For more control over audio playback, use the @code{audioplayer} class.
-## @seealso{sound, record}
+## @seealso{sound, @audioplayer/audioplayer, record}
 ## @end deftypefn
 
-function soundsc (y, fs, nbits, yrange)
+function soundsc (y, fs, nbits, yrange = [])
 
-  if (nargin < 1 || nargin > 4)
+  if (nargin < 1)
     print_usage ();
   endif
 
-  if (nargin < 4)
-    yrange = [];
-  endif
-
   if (nargin < 2 || isempty (fs))
     fs = 8000;
   elseif (nargin == 2 && numel (fs) > 1)
     yrange = fs;
     fs = 8000;
-  elseif (! (isscalar (fs) && (fs > 0)))
+  elseif (! (isscalar (fs) && fs > 0))
     error ("soundsc: sample rate FS must be a positive number");
   endif
 
@@ -102,15 +98,14 @@ endfunction
 
 
 ## Tests of soundsc must not actually play anything.
-
 ## Test input validation
-%!error soundsc ()
-%!error soundsc (1,2,3,4,5)
-%!error soundsc (1, -1)
-%!error soundsc (1, [], 2)
-%!error soundsc (1, [2 1])
-%!error soundsc (1, [1 2 3])
-%!error soundsc (1, 8000, [2 1])
-%!error soundsc (1, 8000, [1 2 3])
-%!error soundsc (1, 8000, 8, [2 1])
-%!error soundsc (1, 8000, 8, [1 2 3])
+%!error <Invalid call> soundsc ()
+%!error <FS must be a positive number> soundsc (1, ones (2,2), 8)
+%!error <FS must be a positive number> soundsc (1, -1)
+%!error <NBITS must be 8, 16, or 24> soundsc (1, [], 2)
+%!error <range must be a 2-element .* vector> soundsc (1, [2 1])
+%!error <range must be a 2-element .* vector> soundsc (1, [1 2 3])
+%!error <range must be a 2-element .* vector> soundsc (1, 8000, [2 1])
+%!error <range must be a 2-element .* vector> soundsc (1, 8000, [1 2 3])
+%!error <range must be a 2-element .* vector> soundsc (1, 8000, 8, [2 1])
+%!error <range must be a 2-element .* vector> soundsc (1, 8000, 8, [1 2 3])
