@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 1994-2020 The Octave Project Developers
+## Copyright (C) 1994-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -24,14 +24,14 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} coth (@var{x})
+## @deftypefn {} {@var{y} =} coth (@var{x})
 ## Compute the hyperbolic cotangent of each element of @var{x}.
 ## @seealso{acoth}
 ## @end deftypefn
 
 function y = coth (x)
 
-  if (nargin != 1)
+  if (nargin < 1)
     print_usage ();
   endif
 
@@ -45,5 +45,4 @@ endfunction
 %! v = [0, 0];
 %! assert (coth (x), v, sqrt (eps));
 
-%!error coth ()
-%!error coth (1, 2)
+%!error <Invalid call> coth ()
