@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 1994-2020 The Octave Project Developers
+## Copyright (C) 1994-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -24,14 +24,14 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} sech (@var{x})
+## @deftypefn {} {@var{y} =} sech (@var{x})
 ## Compute the hyperbolic secant of each element of @var{x}.
 ## @seealso{asech}
 ## @end deftypefn
 
 function y = sech (x)
 
-if (nargin != 1)
+if (nargin < 1)
     print_usage ();
   endif
 
@@ -45,5 +45,4 @@ endfunction
 %! v = [1, -1];
 %! assert (sech (x), v, sqrt (eps));
 
-%!error sech ()
-%!error sech (1, 2)
+%!error <Invalid call> sech ()
