@@ -1,4 +1,9 @@
-## Copyright (C) 2017-2018 David Bateman
+########################################################################
+##
+## Copyright (C) 2017-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {@var{q} =} quad2d (@var{f}, @var{xa}, @var{xb}, @var{ya}, @var{yb})
@@ -124,7 +131,7 @@
 ##
 ## Reference: @nospell{L.F. Shampine},
 ## @cite{@sc{matlab} program for quadrature in 2D}, Applied Mathematics and
-## Computation, pp. 266--274, Vol 1, 2008.
+## Computation, pp.@: 266--274, Vol 1, 2008.
 ##
 ## @seealso{integral2, dblquad, integral, quad, quadgk, quadv, quadl, quadcc,
 ##          trapz, integral3, triplequad}
@@ -226,13 +233,13 @@ function [q, err, iter] = quad2d (f, xa, xb, ya, yb, varargin)
     if (! (isreal (ya) && isscalar (ya)))
       error ("quad2d: YA must be a real scalar or a function");
     endif
-    ya = @(x) ya * ones(rows (x), columns (x));
+    ya = @(x) ya * ones (rows (x), columns (x));
   endif
   if (! is_function_handle (yb))
     if (! (isreal (yb) && isscalar (yb)))
       error ("quad2d: YB must be a real scalar or a function");
     endif
-    yb = @(x) yb * ones(rows (x), columns (x));
+    yb = @(x) yb * ones (rows (x), columns (x));
   endif
 
   iter = 0;
@@ -248,14 +255,14 @@ function [q, err, iter] = quad2d (f, xa, xb, ya, yb, varargin)
     ##   dx = - (a - b) * sin(t) / 2 dt
     ## Now our integral is
     ##   \int_a^b \int_0^1 f(x,y) dydx
-    ## as we already subsitute for "y", so
+    ## as we already substitute for "y", so
     ##   gx(tx) = ((a - b) * cos(tx) + (a + b)) / 2
     ##   gy(ty) = (1 - cos(ty)) / 2
     ##   dydx = (b - a) * sin(tx) * sin(ty) / 4 dtydtx
 
     xtrans = @(tx) ((xa - xb) .* cos (tx) + (xa + xb)) ./ 2;
     ytrans = @(ty) (1 - cos (ty)) ./ 2;
-    ztrans = @(tx, ty) (xb - xa) .* sin(tx) .* sin(ty) ./ 4;
+    ztrans = @(tx, ty) (xb - xa) .* sin (tx) .* sin (ty) ./ 4;
     area = pi ^ 2;
 
     ## Initialize tile list
@@ -350,6 +357,7 @@ function [q, err, iter] = quad2d (f, xa, xb, ya, yb, varargin)
 endfunction
 
 function [q, qerr] = tensorproduct (f, ya, yb, tile, xtrans, ytrans, ztrans, singular)
+
   ## The Shampine TwoD paper proposes using a G3,K7 rule in a tensor product.
   ## I couldn't find a tabulated abscissas and weights of a G3,K7 rule publicly
   ## available, so use a G7,K15 rule from Octave's implementation of quadgk.
@@ -399,8 +407,9 @@ function [q, qerr] = tensorproduct (f, ya, yb, tile, xtrans, ytrans, ztrans, sin
   ty = ty * ones (1, 15);
 
   z = yhalfwidth .* f (x, y) .* ztrans(tx, ty) .* xhalfwidth;
-  q = weights15 * (weights15 * z)';
-  qerr = abs (weights7 * (weights7 * z)' - q);
+  q = weights15 * (weights15 * z).';
+  qerr = abs (weights7 * (weights7 * z).' - q);
+
 endfunction
 
 
@@ -429,13 +438,15 @@ endfunction
 
 %!assert (quad2d (@plus, 1, 2, 3, 4), 5, 1e-10)
 
+%!assert <*62972> (quad2d (@(x,y) 1i*ones (size (x)), 0,1,0,1), 1i)
+
 ## Test input validation
-%!error quad2d ()
-%!error quad2d (@plus)
-%!error quad2d (@plus, 1)
-%!error quad2d (@plus, 1, 2)
-%!error quad2d (@plus, 1, 2, 3)
-%!error quad2d (@plus, 1, 2, 3, 4, "foo")
+%!error <Invalid call> quad2d ()
+%!error <Invalid call> quad2d (@plus)
+%!error <Invalid call> quad2d (@plus, 1)
+%!error <Invalid call> quad2d (@plus, 1, 2)
+%!error <Invalid call> quad2d (@plus, 1, 2, 3)
+%!error <Invalid call> quad2d (@plus, 1, 2, 3, 4, "foo")
 %!error quad2d (0, 1, 2, 3, 4)          # f must be function handle
 %!error quad2d (@plus, 1i, 2, 3, 4)     # real limits
 %!error quad2d (@plus, 1, 2i, 3, 4)     # real limits
