@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2006-2021 The Octave Project Developers
+## Copyright (C) 2006-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -28,6 +28,12 @@
 ##
 ## @table @code
 ## @item Octave:abbreviated-property-match
+## If the @code{Octave:abbreviated-property-match} warning is enabled, a
+## warning is printed if a non-exact or ambiguous match is being used for a
+## operation specifying an object property.  For example, for a graphics
+## object, @var{fig}, with the property @qcode{'displayname'},
+## @code{get (@var{fig}, 'dis')} elicits a warning if the
+## @code{Octave:abbreviated-property-match} warning is enabled.
 ## By default, the @code{Octave:abbreviated-property-match} warning is enabled.
 ##
 ## @item Octave:addpath-pkg
@@ -135,9 +141,12 @@
 ## By default, the @code{Octave:autoload-relative-file-name} warning is
 ## enabled.
 ##
-## @item Octave:built-in-variable-assignment
-## By default, the @code{Octave:built-in-variable-assignment} warning is
-## enabled.
+## @item Octave:charmat-truncated
+## If the @code{Octave:charmat-truncated} warning is enabled, a warning is
+## printed when a character matrix with multiple rows is converted to a string.
+## In this case, the Octave interpreter keeps only the first row and discards
+## the others.
+## By default, the @code{Octave:charmat-truncated} warning is enabled.
 ##
 ## @item Octave:classdef-to-struct
 ## If the @code{Octave:classdef-to-struct} warning is enabled, a warning
@@ -169,6 +178,13 @@
 ## different file target than the programmer intended is being used.
 ## By default, the @code{Octave:data-file-in-path} warning is enabled.
 ##
+## @item Octave:datevec:date-format-spec
+## If the @code{Octave:datevec:date-format-spec} warning is enabled, a warning
+## is printed if the date format specification contains questionable date or
+## time specifiers.  Typical bad patterns are using uppercase date specifiers
+## or lowercase time specifiers.
+## By default, the @code{Octave:datevec:date-format-spec} warning is enabled.
+##
 ## @item Octave:deprecated-function
 ## If the @code{Octave:deprecated-function} warning is enabled, a
 ## warning is issued when Octave encounters a function that is obsolete and
@@ -181,6 +197,11 @@
 ## scheduled for removal from Octave.
 ## By default, the @code{Octave:deprecated-keyword} warning is enabled.
 ##
+## @item Octave:deprecated-option
+## If the @code{Octave:deprecated-option} warning is enabled, a
+## warning is issued when an obsolete option or input to a function is used.
+## By default, the @code{Octave:deprecated-option} warning is enabled.
+##
 ## @item Octave:deprecated-property
 ## If the @code{Octave:deprecated-property} warning is enabled, a
 ## warning is issued when Octave encounters a graphics property that
@@ -230,6 +251,12 @@
 ## printed for implicit conversions of complex numbers to real numbers.
 ## By default, the @code{Octave:imag-to-real} warning is disabled.
 ##
+## @item Octave:infinite-loop
+## If the @code{Octave:infinite-loop} warning is enabled, a warning is
+## printed when an infinite loop is detected such as @code{for i = 1:Inf} or
+## @code{while (1)}.
+## By default, the @code{Octave:infinite-loop} warning is enabled.
+##
 ## @item Octave:language-extension
 ## Print warnings when using features that are unique to the Octave
 ## language and that may still be missing in @sc{matlab}.
@@ -247,6 +274,9 @@
 ## By default, the @code{Octave:legacy-function} warning is enabled.
 ##
 ## @item Octave:logical-conversion
+## If the @code{Octave:logical-conversion} warning is enabled, a warning is
+## printed if an implicit conversion of an array from numerical to boolean
+## occurs and any of the elements in the array are not equal to zero or one.
 ## By default, the @code{Octave:logical-conversion} warning is enabled.
 ##
 ## @item Octave:lu:sparse_input
@@ -291,10 +321,27 @@
 ## By default, the @code{Octave:neg-dim-as-zero} warning is disabled.
 ##
 ## @item Octave:noninteger-range-as-index
+## If the @code{Octave:noninteger-range-as-index} warning is enabled, a warning
+## is printed if an array is indexed with a range that contains non-integer
+## values.  For example,
+##
+## @example
+## @group
+## a = [1 2 3 4 5];
+## b = 2.2:4.2
+## @result{} 1.2  2.2  3.2
+## a(b)
+## @result{} 2 3 4
+## @end group
+## @end example
+##
+## @noindent
+## elicits a warning if the @code{Octave:noninteger-range-as-index} warning is
+## enabled.
 ## By default, the @code{Octave:noninteger-range-as-index} warning is enabled.
 ##
 ## @item Octave:num-to-str
-## If the @code{Octave:num-to-str} warning is enable, a warning is
+## If the @code{Octave:num-to-str} warning is enabled, a warning is
 ## printed for implicit conversions of numbers to their UTF-8 encoded character
 ## equivalents when strings are constructed using a mixture of strings and
 ## numbers in matrix notation.  For example,
@@ -319,6 +366,11 @@
 ## By default, the @code{Octave:possible-matlab-short-circuit-operator} warning
 ## is enabled.
 ##
+## @item Octave:pow2:imaginary-ignored
+## If the @code{Octave:pow2:imaginary-ignored} warning is enabled, a warning is
+## printed if either input to @code{pow2} is complex.
+## By default, the @code{Octave:pow2:imaginary-ignored} warning is enabled.
+##
 ## @item Octave:recursive-path-search
 ## If the @code{Octave:recursive-path-search} warning is enabled, Octave
 ## will issue a warning if @code{addpath} is used with double trailing
@@ -359,6 +411,9 @@
 ## By default, the @code{Octave:single-quote-string} warning is disabled.
 ##
 ## @item Octave:sqrtm:SingularMatrix
+## If the @code{Octave:sqrtm:SingularMatrix} warning is enabled, a warning is
+## printed if the matrix square root function @code{sqrtm} is called with an
+## input matrix that is singular.
 ## By default, the @code{Octave:sqrtm:SingularMatrix} warning is enabled.
 ##
 ## @item Octave:str-to-num
@@ -377,12 +432,19 @@
 ## elicits a warning if the @code{Octave:str-to-num} warning is enabled.
 ## By default, the @code{Octave:str-to-num} warning is disabled.
 ##
-## @item Octave:text_interpreter
-## If the @code{Octave:text_interpreter} warning is enabled, a warning is
-## printed when the @qcode{"interpreter"} property of a text graphics object
-## is set to the unsupported value of @qcode{"latex"}.  Even when enabled,
-## the warning message is printed just once per Octave session.
-## By default, the @code{Octave:glyph-render} warning is enabled.
+## @item Octave:LaTeX:internal-error
+## If the @code{Octave:LaTeX:internal-error} warning is enabled, a warning is
+## printed whenever the @LaTeX{} renderer for text in plots encounters an
+## issue.
+## By default, the @code{Octave:LaTeX:internal-error} warning is enabled.
+##
+## @item Octave:unimplemented-matlab-functionality
+## If the @code{Octave:unimplemented-matlab-functionality} warning is enabled,
+## a warning is printed when a @sc{matlab} code construct is used which the
+## Octave interpreter parses as valid, but for which Octave does not yet
+## implement the functionality.
+## By default, the @code{Octave:unimplemented-matlab-functionality} warning is
+## enabled.
 ##
 ## @item Octave:variable-switch-label
 ## If the @code{Octave:variable-switch-label} warning is enabled, Octave
@@ -397,5 +459,5 @@ function warning_ids ()
 endfunction
 
 
-## Mark file as being tested.  No real test needed for a documentation .m file
+## Mark file as tested.  No test needed for a documentation m-file.
 %!assert (1)
