@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2008-2021 The Octave Project Developers
+## Copyright (C) 2008-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -23,14 +23,21 @@
 ##
 ########################################################################
 
-## This function does all the work of imfinfo.  It exists here as private
-## function so that imfinfo can use other functions if imformats is
-## configured to.  It is also needed so that imformats can create a
-## function handle for it.
+## -*- texinfo -*-
+## @deftypefn {} {@var{info} =} __imfinfo__ (@var{filename})
+##
+## This function does all the work of @code{imfinfo}.
+##
+## It exists here as private function so that @code{imfinfo} can use other
+## functions if @code{imformats} is configured to.  It is also needed so that
+## @code{imformats} can create a function handle for it.
+##
+## @seealso{imfinfo}
+## @end deftypefn
 
 function info = __imfinfo__ (filename)
 
-  if (nargin != 1)
+  if (nargin < 1)
     print_usage ("imfinfo");
   elseif (! ischar (filename))
     error ("imfinfo: FILENAME must be a string");
