@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2006-2020 The Octave Project Developers
+## Copyright (C) 2006-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -43,7 +43,7 @@
 
 function [nest, iter] = normest (A, tol = 1e-6)
 
-  if (nargin != 1 && nargin != 2)
+  if (nargin < 1)
     print_usage ();
   endif
 
@@ -96,8 +96,7 @@ endfunction
 %! assert (normest (A), norm (A), 1e-6);
 
 ## Test input validation
-%!error normest ()
-%!error normest (1, 2, 3)
+%!error <Invalid call> normest ()
 %!error <A must be a numeric .* matrix> normest ([true true])
 %!error <A must be .* 2-D matrix> normest (ones (3,3,3))
 %!error <TOL must be a real scalar> normest (1, [1, 2])
