@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 1993-2020 The Octave Project Developers
+## Copyright (C) 1993-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -24,8 +24,8 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {} {} rank (@var{A})
-## @deftypefnx {} {} rank (@var{A}, @var{tol})
+## @deftypefn  {} {@var{k} =} rank (@var{A})
+## @deftypefnx {} {@var{k} =} rank (@var{A}, @var{tol})
 ## Compute the rank of matrix @var{A}, using the singular value decomposition.
 ##
 ## The rank is taken to be the number of singular values of @var{A} that are
@@ -79,7 +79,11 @@
 ## @seealso{null, orth, sprank, svd, eps}
 ## @end deftypefn
 
-function retval = rank (A, tol)
+function k = rank (A, tol)
+
+  if (nargin < 1)
+    print_usage ();
+  endif
 
   if (nargin == 1)
     sigma = svd (A);
@@ -92,14 +96,12 @@ function retval = rank (A, tol)
         tolerance = max (size (A)) * sigma (1) * eps;
       endif
     endif
-  elseif (nargin == 2)
+  else
     sigma = svd (A);
     tolerance = tol;
-  else
-    print_usage ();
   endif
 
-  retval = sum (sigma > tolerance);
+  k = sum (sigma > tolerance);
 
 endfunction
 
