@@ -1,4 +1,9 @@
-## Copyright (C) 2006-2019 Bill Denney
+########################################################################
+##
+## Copyright (C) 2006-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,9 +20,11 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} compare_versions (@var{v1}, @var{v2}, @var{operator})
+## @deftypefn {} {@var{tf} =} compare_versions (@var{v1}, @var{v2}, @var{operator})
 ## Compare two version strings using the given @var{operator}.
 ##
 ## This function assumes that versions @var{v1} and @var{v2} are arbitrarily
@@ -53,13 +60,9 @@
 ## @qcode{">="}
 ## greater than or equal to
 ##
-## @item
-## @qcode{"!="}
+## @item @qcode{"!="}, @qcode{"~="}
 ## not equal
 ##
-## @item
-## @qcode{"~="}
-## not equal
 ## @end itemize
 ##
 ## Note that version @qcode{"1.1-test2"} will compare as greater than
@@ -69,9 +72,7 @@
 ## @code{double ("1").}
 ## @end deftypefn
 
-## Author: Bill Denney <denney@seas.upenn.edu>
-
-function out = compare_versions (v1, v2, operator)
+function tf = compare_versions (v1, v2, operator)
 
   if (nargin != 3)
     print_usage ();
@@ -164,18 +165,18 @@ function out = compare_versions (v1, v2, operator)
 
   if (isempty (firstdiff))
     ## They're equal.
-    out = equal_op;
+    tf = equal_op;
   elseif (lt_op || gt_op)
     ## They're correctly less than or greater than.
-    out = (vcmp(firstdiff) > 0);
+    tf = (vcmp(firstdiff) > 0);
   else
     ## They're not correctly less than or greater than, and they're not equal.
-    out = false;
+    tf = false;
   endif
 
   ## Reverse the output if not is given.
   if (not_op)
-    out = ! out;
+    tf = ! tf;
   endif
 
 endfunction
@@ -222,10 +223,9 @@ endfunction
 %!assert (compare_versions ("0.1", "0.1", "~="), false)
 
 ## Test input validation
-%!error compare_versions ()
-%!error compare_versions (1)
-%!error compare_versions (1,2)
-%!error compare_versions (1,2,3,4)
+%!error <Invalid call> compare_versions ()
+%!error <Invalid call> compare_versions (1)
+%!error <Invalid call> compare_versions (1,2)
 %!error <V1 and V2 must be strings> compare_versions (0.1, "0.1", "==")
 %!error <V1 and V2 must be strings> compare_versions ("0.1", 0.1, "==")
 %!error <V1 and V2 must be a single row> compare_versions (["0";".";"1"], "0.1", "==")
