@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2019-2021 The Octave Project Developers
+## Copyright (C) 2019-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -36,7 +36,7 @@
 
 function mustBeReal (x)
 
-  if (nargin != 1)
+  if (nargin < 1)
     print_usage ();
   endif
 
