@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2005-2020 The Octave Project Developers
+## Copyright (C) 2005-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -485,12 +485,13 @@
 function [xopt, fmin, errnum, extra] = glpk (c, A, b, lb, ub, ctype, vartype, sense, param)
 
   ## If there is no input output the version and syntax
-  if (nargin < 3 || nargin > 9)
+  if (nargin < 3)
     print_usage ();
   endif
 
-  if (all (size (c) > 1) || iscomplex (c) || ischar (c))
-    error ("glpk: C must be a real vector");
+   if (! isvector (c) || iscomplex (c) || ischar (c) || any (isinf (c))
+       || any (isnan (c)))
+     error ("glpk: C must be a real vector with finite values");
   endif
   nx = length (c);
   ## Force column vector.
@@ -504,9 +505,13 @@ function [xopt, fmin, errnum, extra] = glpk (c, A, b, lb, ub, ctype, vartype, se
   if (! isreal (A))
     error ("glpk: A must be real valued, not %s", typeinfo (A));
   endif
+  if (any (isinf (A(:))) || any (isnan (A(:))))
+    error ("glpk: The values in A must be finite");
+  endif
+
   [nc, nxa] = size (A);
   if (nxa != nx)
-    error ("glpk: A must be %d by %d, not %d by %d",
+    error ("glpk: A must be %d-by-%d, not %d-by-%d",
            nc, nx, rows (A), columns (A));
   endif
 
@@ -516,7 +521,10 @@ function [xopt, fmin, errnum, extra] = glpk (c, A, b, lb, ub, ctype, vartype, se
     error ("glpk: B cannot be an empty vector");
   endif
   if (! isreal (b) || length (b) != nc)
-    error ("glpk: B must be a real valued %d by 1 vector", nc);
+    error ("glpk: B must be a real-valued %d-by-1 vector", nc);
+  endif
+  if (any (! isfinite (b(:))))
+    error ("glpk: The values in B must be finite");
   endif
 
   ## 4) Vector with the lower bound of each variable
@@ -524,8 +532,9 @@ function [xopt, fmin, errnum, extra] = glpk (c, A, b, lb, ub, ctype, vartype, se
   if (nargin > 3)
     if (isempty (lb))
       lb = zeros (nx, 1);
-    elseif (! isreal (lb) || all (size (lb) > 1) || length (lb) != nx)
-      error ("glpk: LB must be a real valued %d by 1 column vector", nx);
+    elseif (! isreal (lb) || all (size (lb) > 1) || length (lb) != nx
+            || any (isnan (lb)))
+      error ("glpk: LB must be a real-valued %d-by-1 column vector", nx);
     endif
   else
     lb = zeros (nx, 1);
@@ -536,8 +545,9 @@ function [xopt, fmin, errnum, extra] = glpk (c, A, b, lb, ub, ctype, vartype, se
   if (nargin > 4)
     if (isempty (ub))
       ub = Inf (nx, 1);
-    elseif (! isreal (ub) || all (size (ub) > 1) || length (ub) != nx)
-      error ("glpk: UB must be a real valued %d by 1 column vector", nx);
+    elseif (! isreal (ub) || all (size (ub) > 1) || length (ub) != nx
+            || any (isnan (ub)))
+      error ("glpk: UB must be a real-valued %d-by-1 column vector", nx);
     endif
   else
     ub = Inf (nx, 1);
@@ -549,7 +559,7 @@ function [xopt, fmin, errnum, extra] = glpk (c, A, b, lb, ub, ctype, vartype, se
     if (isempty (ctype))
       ctype = repmat ("S", nc, 1);
     elseif (! ischar (ctype) || all (size (ctype) > 1) || length (ctype) != nc)
-      error ("glpk: CTYPE must be a char valued vector of length %d", nc);
+      error ("glpk: CTYPE must be a char vector of length %d", nc);
     elseif (! all (ctype == "F" | ctype == "U" | ctype == "S"
                    | ctype == "L" | ctype == "D"))
       error ("glpk: CTYPE must contain only F, U, S, L, or D");
@@ -565,7 +575,7 @@ function [xopt, fmin, errnum, extra] = glpk (c, A, b, lb, ub, ctype, vartype, se
       vartype = repmat ("C", nx, 1);
     elseif (! ischar (vartype) || all (size (vartype) > 1)
             || length (vartype) != nx)
-      error ("glpk: VARTYPE must be a char valued vector of length %d", nx);
+      error ("glpk: VARTYPE must be a char vector of length %d", nx);
     elseif (! all (vartype == "C" | vartype == "I"))
       error ("glpk: VARTYPE must contain only C or I");
     endif
@@ -579,7 +589,8 @@ function [xopt, fmin, errnum, extra] = glpk (c, A, b, lb, ub, ctype, vartype, se
   if (nargin > 7)
     if (isempty (sense))
       sense = 1;
-    elseif (ischar (sense) || all (size (sense) > 1) || ! isreal (sense))
+    elseif (ischar (sense) || all (size (sense) > 1) || ! isreal (sense)
+            || any (! isfinite (sense)))
       error ("glpk: SENSE must be an integer value");
     elseif (sense >= 0)
       sense = 1;
@@ -656,3 +667,10 @@ endfunction
 %!   sense, param);
 %! assert (fmin, c' * xmin);
 %! assert (A * xmin, b);
+
+%!error <C .* finite values> glpk (NaN, 2, 3)
+%!error <A must be finite> glpk (1, NaN, 3)
+%!error <B must be finite> glpk (1, 2, NaN)
+%!error <LB must be a real-valued> glpk (1, 2, 3, NaN)
+%!error <UB must be a real-valued> glpk (1, 2, 3, 4, NaN)
+%!error <SENSE must be .* integer> glpk (1, 2, 3, 4, 5, "F", "C", NaN)
