@@ -1,21 +1,27 @@
-## Copyright (C) 2007-2017 John W. Eaton
-## Copyright (C) 2009 VZLU Prague
+########################################################################
+##
+## Copyright (C) 2007-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} optimset ()
@@ -118,6 +124,8 @@ function retval = optimset (varargin)
   nargs = nargin;
 
   opts = __all_opts__ ();
+  ## Skip validation if we're in the internal query.
+  validation = ! isempty (opts);
 
   if (nargs == 0)
     if (nargout == 0)
@@ -142,47 +150,72 @@ function retval = optimset (varargin)
     ## Should we be checking to ensure that the field names are expected?
     old = varargin{1};
     new = varargin{2};
-    fnames = fieldnames (old);
-    ## skip validation if we're in the internal query
-    validation = ! isempty (opts);
-    for [val, key] = new
-      if (validation)
-        ## Case insensitive lookup in all options.
-        i = strncmpi (opts, key, length (key));
-        nmatch = sum (i);
-        ## Validate option.
-        if (nmatch == 1)
-          key = opts{find (i)};
-        elseif (nmatch == 0)
-          warning ("optimset: unrecognized option: %s", key);
-        else
-          fmt = sprintf ("optimset: ambiguous option: %%s (%s%%s)",
-                         repmat ("%s, ", 1, nmatch-1));
-          warning (fmt, key, opts{i});
-        endif
-      endif
-      old.(key) = val;
-    endfor
-    retval = old;
+    useempty = false; # Matlab drops empty new fields, too.
+    retval = setoptionfields (opts, old, new, validation, useempty);
   elseif (rem (nargs, 2) && isstruct (varargin{1}))
     ## Set values in old from name/value pairs.
+    old = varargin{1};
     pairs = reshape (varargin(2:end), 2, []);
-    retval = optimset (varargin{1}, cell2struct (pairs(2, :), pairs(1, :), 2));
+    new = cell2struct (pairs(2, :), pairs(1, :), 2);
+    useempty = true; # Matlab preserves empty arguments, too.
+    retval = setoptionfields (opts, old, new, validation, useempty);
   elseif (rem (nargs, 2) == 0)
     ## Create struct.
     ## Default values are replaced by those specified by name/value pairs.
+    old = struct ();
     pairs = reshape (varargin, 2, []);
-    retval = optimset (struct (), cell2struct (pairs(2, :), pairs(1, :), 2));
+    new = cell2struct (pairs(2, :), pairs(1, :), 2);
+    useempty = true; # Matlab preserves empty arguments, too.
+    retval = setoptionfields (opts, old, new, validation, useempty);
   else
     print_usage ();
   endif
 
 endfunction
 
+function retval = setoptionfields (opts, old, new, validation, useempty)
+
+  for [val, key] = new
+    if (validation)
+      ## Case insensitive lookup in all options.
+      i = strncmpi (opts, key, length (key));
+      nmatch = sum (i);
+      ## Validate option.
+      if (nmatch == 1)
+        key = opts{find (i)};
+      elseif (nmatch == 0)
+        warning ("optimset: unrecognized option: %s", key);
+      else
+        fmt = sprintf ("optimset: ambiguous option: %%s (%s%%s)",
+                       repmat ("%s, ", 1, nmatch-1));
+        warning (fmt, key, opts{i});
+      endif
+    endif
+    if (useempty || ! isempty (val))
+      old.(key) = val;
+    endif
+  endfor
+  retval = old;
+
+endfunction
+
 
 %!assert (isfield (optimset (), "TolFun"))
 %!assert (isfield (optimset ("tolFun", 1e-3), "TolFun"))
 %!assert (optimget (optimset ("tolx", 1e-2), "tOLx"), 1e-2)
+%!test
+%! old = optimset ();
+%! old.TolX = 1e-2;
+%! new = optimset ();
+%! new.TolFun = 1e-3;
+%! joint = optimset (old, new);
+%! assert (joint.TolX, 1e-2);
+%! assert (joint.TolFun, 1e-3);
+
+## Test preserving empty values given as arguments
+%!test
+%! opts = optimset ("TypicalX", []);
+%! assert (isempty (opts.TypicalX));
 
 ## Test input validation
 %!error optimset ("1_Parameter")
