@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2017-2021 The Octave Project Developers
+## Copyright (C) 2017-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -53,17 +53,17 @@
 ## @seealso{yticklabels, xticks, zticks, rticks, thetaticks, get, set}
 ## @end deftypefn
 
-function retval = yticks (varargin)
+function tickval = yticks (varargin)
 
   hax = [];
   switch (nargin)
     case 0
-      retval = get (gca , "ytick");  # will error if no ytick exists.
+      tickval = get (gca , "ytick");  # will error if no ytick exists.
       return;
 
     case 1
       if (isaxes (varargin{1}))
-        retval = get (varargin{1}, "ytick");
+        tickval = get (varargin{1}, "ytick");
         return;
       else
         arg = varargin{1};
@@ -99,7 +99,7 @@ function retval = yticks (varargin)
     arg = tolower (arg);
     switch (arg)
       case "mode"
-        retval = get (hax, "ytickmode");
+        tickval = get (hax, "ytickmode");
 
       case {"auto", "manual"}
         if (nargout > 0)
@@ -124,7 +124,7 @@ endfunction
 %! hf = figure ("visible", "off");
 %! unwind_protect
 %!   set (gca, "ytickmode", "auto");
-%!   hax = gca;
+%!   hax = gca ();
 %!   vals1 = yticks;
 %!   assert (yticks (hax), vals1);
 %!   mode1 = yticks ("mode");
@@ -145,7 +145,7 @@ endfunction
 %!test
 %! hf = figure ("visible", "off");
 %! unwind_protect
-%!   hax = gca;
+%!   hax = gca ();
 %!   fail ("yticks (-1, [0 1])", "HAX must be a handle to an axes");
 %!   fail ("tmp = yticks (hax, [0 1])", "too many output arguments");
 %!   fail ("tmp = yticks (hax, 'auto')", "too many .* for arg: auto");
