@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2007-2022 The Octave Project Developers
+## Copyright (C) 2007-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -55,12 +55,12 @@
 ## @seealso{xlim, ylim, axis, set, get, gca}
 ## @end deftypefn
 
-function retval = zlim (varargin)
+function zlimits = zlim (varargin)
 
-  ret = __axis_limits__ ("zlim", varargin{:});
+  lims = __axis_limits__ ("zlim", varargin{:});
 
-  if (! isempty (ret))
-    retval = ret;
+  if (! isempty (lims))
+    zlimits = lims;
   endif
 
 endfunction
