@@ -1,4 +1,9 @@
-## Copyright (C) 2013-2018 Mike Miller
+########################################################################
+##
+## Copyright (C) 2013-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} waterfall (@var{x}, @var{y}, @var{z})
@@ -45,7 +52,8 @@
 ## by supplying a color matrix, @var{c}.
 ##
 ## Any property/value pairs are passed directly to the underlying surface
-## object.
+## object.  The full list of properties is documented at
+## @ref{Surface Properties}.
 ##
 ## If the first argument @var{hax} is an axes handle, then plot into this axes,
 ## rather than the current axes returned by @code{gca}.
@@ -53,11 +61,10 @@
 ## The optional return value @var{h} is a graphics handle to the created
 ## surface object.
 ##
-## @seealso{meshz, mesh, meshc, contour, surf, surface, ribbon, meshgrid, hidden, shading, colormap, caxis}
+## @seealso{meshz, mesh, meshc, contour, surf, surface, ribbon, meshgrid,
+## hidden, shading, colormap, caxis}
 ## @end deftypefn
 
-## Author: Mike Miller <mtmiller@ieee.org>
-
 function h = waterfall (varargin)
 
   htmp = meshz (varargin{:});
