@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2016-2021 The Octave Project Developers
+## Copyright (C) 2016-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -59,10 +59,6 @@
 
 function retval = __opengl_info__ ()
 
-  if (nargin != 0)
-    print_usage ();
-  endif
-
   [info, msg] = gl_info ();
 
   if (! isempty (msg))
