@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2002-2021 The Octave Project Developers
+## Copyright (C) 2002-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -30,6 +30,7 @@
 ## @deftypefnx {} {} close all
 ## @deftypefnx {} {} close all hidden
 ## @deftypefnx {} {} close all force
+## @deftypefnx {} {@var{status} =} close (@dots{})
 ## Close figure window(s).
 ##
 ## When called with no arguments, close the current figure.  This is equivalent
@@ -48,6 +49,9 @@
 ## even when @qcode{"closerequestfcn"} has been altered to prevent closing the
 ## window.
 ##
+## If the optional output @var{status} is requested then Octave returns 1 if
+## the figure windows were closed successfully.
+##
 ## Implementation Note: @code{close} operates by making the handle @var{h} the
 ## current figure, and then calling the function specified by the
 ## @qcode{"closerequestfcn"} property of the figure.  By default, the function
@@ -59,13 +63,11 @@
 ## @seealso{closereq, delete}
 ## @end deftypefn
 
-function retval = close (arg1, arg2)
+function status = close (arg1, arg2)
 
   figs = [];
 
-  if (nargin > 2)
-    print_usage ();
-  elseif (nargin == 0)
+  if (nargin == 0)
     ## Close current figure.
     ## Can't use gcf because it opens a new plot window if one does not exist.
     figs = get (0, "currentfigure");
@@ -124,7 +126,7 @@ function retval = close (arg1, arg2)
   endif
 
   if (nargout > 0)
-    retval = 1;
+    status = 1;
   endif
 
 endfunction
@@ -181,7 +183,6 @@ endfunction
 %! end_unwind_protect
 
 ## Test input validation
-%!error close (1,2,3)
 %!error <first argument must be "all", a figure handle> close ({"all"})
 %!error <first argument must be "all", a figure handle> close (-1)
 %!error <second argument must be "hidden"> close all hid
