@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2012-2022 The Octave Project Developers
+## Copyright (C) 2012-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -395,10 +395,10 @@ endfunction
 function [h, sout] = createscatter (s, par)
 
   if (isempty (s.properties.zdata))
-    ## 2D scatter
+    ## 2-D scatter
     h = scatter (s.properties.xdata, s.properties.ydata);
   else
-    ## 3D scatter
+    ## 3-D scatter
     h = scatter3 (s.properties.xdata, s.properties.ydata, s.properties.zdata);
   endif
 
@@ -441,9 +441,9 @@ endfunction
 function [h, sout, pout] = createhg (s, p, par, hilev)
 
   ## Here we infer from properties the type of hggroup we should build
-  ## an call corresponding high level functions
+  ## and call the corresponding high level functions.
   ## We manually set "hold on" to avoid next hggroup be deleted
-  ## the proper value of axes "nextplot" will finally be recovered
+  ## the proper value of axes "nextplot" will finally be recovered.
 
   hold on;
   if (hilev)
@@ -475,6 +475,12 @@ function [h, sout, pout] = createhg (s, p, par, hilev)
     s.special = [];
   endif
 
+  ## Check for polar plots with special "polar_grid" object
+  ## FIXME: A hack to fix bug #62093.
+  if (strcmp (s.properties.tag, "polar_grid"))
+    s.properties.handlevisibility = "off";
+  endif
+
   sout = s;
   pout = p;
 
@@ -536,7 +542,7 @@ function [h, sout, pout] = createhg_hilev (s, p, par)
                                "udatasource", "vdatasource", "wdatasource"});
 
   elseif (isfield (fields, "format"))
-    ##errorbar
+    ## errorbar
     form = s.properties.format;
     xdata = s.properties.xdata;
     ydata = s.properties.ydata;
@@ -600,7 +606,7 @@ function [h, sout, pout] = createhg_hilev (s, p, par)
       xdata = [];
       ydata = [];
 
-      ##build x/y matrix
+      ## Build x/y matrix
       nbar = length (bargroup);
       tmp = struct ("handle", NaN, "type", "", "children", [], "special", []);
       for ii = 1:(nbar - 1)
