@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 1995-2020 The Octave Project Developers
+## Copyright (C) 1995-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -24,7 +24,7 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} detrend (@var{x}, @var{p})
+## @deftypefn {} {@var{y} =} detrend (@var{x}, @var{p})
 ## If @var{x} is a vector, @code{detrend (@var{x}, @var{p})} removes the
 ## best fit of a polynomial of order @var{p} from the data @var{x}.
 ##
@@ -42,7 +42,7 @@
 
 function y = detrend (x, p = 1)
 
-  if (nargin < 1 || nargin > 2)
+  if (nargin < 1)
     print_usage ();
   endif
 
@@ -55,7 +55,7 @@ function y = detrend (x, p = 1)
   elseif (ischar (p) && strcmpi (p, "linear"))
     p = 1;
   elseif (! isscalar (p) || p < 0 || p != fix (p))
-    error ("detrend: P must be \"constant\", \"linear\", or a positive integer");
+    error ('detrend: P must be "constant", "linear", or a positive integer');
   endif
 
   [m, n] = size (x);
@@ -101,11 +101,9 @@ endfunction
 %! assert (abs (y(:)) < 20*eps);
 
 ## Test input validation
-%!error detrend ()
-%!error detrend (1, 2, 3)
+%!error <Invalid call> detrend ()
 %!error detrend ("a")
 %!error detrend (true)
 %!error detrend (1, "invalid")
 %!error detrend (1, -1)
 %!error detrend (1, 1.25)
-
