@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2004-2021 The Octave Project Developers
+## Copyright (C) 2004-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -27,7 +27,7 @@
 ## public domain.
 
 ## -*- texinfo -*-
-## @deftypefn {} {} nthroot (@var{x}, @var{n})
+## @deftypefn {} {@var{y} =} nthroot (@var{x}, @var{n})
 ##
 ## Compute the real (non-complex) @var{n}-th root of @var{x}.
 ##
@@ -106,9 +106,8 @@ endfunction
 %! assert (lastwarn (), warnmsg);
 
 ## Test input validation
-%!error nthroot ()
-%!error nthroot (1)
-%!error nthroot (1,2,3)
+%!error <Invalid call> nthroot ()
+%!error <Invalid call> nthroot (1)
 %!error <X must not contain complex values> nthroot (1+j, 2)
 %!error <N must be a real nonzero scalar> nthroot (1, i)
 %!error <N must be a real nonzero scalar> nthroot (1, [1 2])
