@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 1996-2021 The Octave Project Developers
+## Copyright (C) 1996-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -24,7 +24,7 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} empirical_pdf (@var{x}, @var{data})
+## @deftypefn {} {@var{pdf} =} empirical_pdf (@var{x}, @var{data})
 ## For each element of @var{x}, compute the probability density function (PDF)
 ## at @var{x} of the empirical distribution obtained from the
 ## univariate sample @var{data}.
@@ -68,7 +68,6 @@ endfunction
 %!assert (empirical_pdf (2, [1 2 3 2]), 0.5)
 
 ## Test input validation
-%!error empirical_pdf ()
-%!error empirical_pdf (1)
-%!error empirical_pdf (1,2,3)
+%!error <Invalid call> empirical_pdf ()
+%!error <Invalid call> empirical_pdf (1)
 %!error empirical_inv (1, ones (2))
