@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2008-2021 The Octave Project Developers
+## Copyright (C) 2008-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -24,7 +24,7 @@
 ########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} regexptranslate (@var{op}, @var{s})
+## @deftypefn {} {@var{str} =} regexptranslate (@var{op}, @var{s})
 ## Translate a string for use in a regular expression.
 ##
 ## This may include either wildcard replacement or special character escaping.
@@ -59,7 +59,7 @@
 ## @seealso{regexp, regexpi, regexprep}
 ## @end deftypefn
 
-function y = regexptranslate (op, s)
+function str = regexptranslate (op, s)
 
   if (nargin != 2)
     print_usage ();
@@ -71,11 +71,11 @@ function y = regexptranslate (op, s)
 
   op = tolower (op);
   if (strcmp ("wildcard", op))
-    y = strrep (strrep (strrep (s, '.', '\.'),
-                                   '*', '.*'),
-                                   '?', '.');
+    str = strrep (strrep (strrep (s, '.', '\.'),
+                                     '*', '.*'),
+                                     '?', '.');
   elseif (strcmp ("escape", op))
-    y = regexprep (s, '([][(){}.*+?^$|\\])', '\\$1');
+    str = regexprep (s, '([][(){}.*+?^$|\\])', '\\$1');
   else
     error ("regexptranslate: invalid operation OP");
   endif
@@ -89,6 +89,6 @@ endfunction
 ## Test input validation
 %!error <Invalid call to regexptranslate> regexptranslate ()
 %!error <Invalid call to regexptranslate> regexptranslate ("wildcard")
-%!error <Invalid call to regexptranslate> regexptranslate ("a", "b", "c")
+%!error <called with too many inputs> regexptranslate ("a", "b", "c")
 %!error <invalid operation> regexptranslate ("foo", "abc")
 %!error <operation OP must be a string> regexptranslate (10, "abc")
