@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2000-2020 The Octave Project Developers
+## Copyright (C) 2000-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -55,7 +55,7 @@
 
 function [d, s] = weekday (d, format = "short")
 
-  if (nargin < 1 || nargin > 2)
+  if (nargin < 1)
     print_usage ();
   endif
 
